 Globals [ money-offered price-offered       ; variables that handle the money exchanged in trades
          goods-exchanged                   ; variable that handles the 'needs' or 'wants' exchanged in trades
          plague                            ; controls the 'epidemics'
          
          harshness-memory                  ; remembers the initial user setting for the Renewable-Harshness slider (used in the Environments Disruption button)
          max-renewable-resources-memory    ; remembers the initial user setting for the Max-Renewable-Resources slider 
          max-price-needs max-price-wants   ; used to prevent trades if the agent has nothing to trade
          
          initial-wave                      ; used track the user desire to upgrade the agents' economic 'knowledge'.
          tax                               ; used to 'tax' adults to pay for 'child benefits'
          trade-minimum                     ; variable governing the minimum possible trade in this system.
          wealthdeath
          wealthdeathno
          death-child-dep
          rankdeath1 rankdeath2 rankdeath0
          
          
          
             ;  The following are all graphing variables.
          
          birth-rate1 death-rate-adults
          trading-setting totalpop1 trade_innovate0 trade_innovate1 fecundity1
          ave-death-age1 death-rate-adults1 beggers1 act-of-charity1 death-rate1
          
          
          food-production                         ; tracks 'needs' harvesting over a single iteration 
          goods-production                        ; tracks 'wants' harvesting over a single iteration
          volume-needs volume-wants               ; tracks the aggregate trade of 'wants' and 'needs'
          economy-needs economy-wants             ; tracks the money exchanged for 'wants' and 'needs'
          totalpop                                ; tracks population
          peak-population                         ; remembers peak population
          fecundity death-rate birth-rate         ; tracks what the variable name says  
          beggers act-of-charity                  ; tracks the agents seeking charity and those giving charity
          
          death-starvation death-age              ; death-* tracks the causes of death. Death-child tracks infant mortality.
          death-epidemic death-accident 
          death-disease death-child
          
          ave-death-age                           ; tracks the average death age
          
          ;      All the following variables ending in '1' aggregate their through multiple iterations 
          ;      whenever the user hasn't set the simulator to graph every iteration. It creates averages for the graphing intervals so the trends can more easily be seen,
          ;      especially for the low populations required by personal computers.
          
          goods-production1
          surplus1
          per-Capita-Productivity1
          bottom-third bottom-third1 
          middle-third middle-third1 
          top-third top-third1
          all-wealth1
          needs-pricing1
          wants-pricing1
          trade-needs trade-needs1
          trade-wants trade-wants1
          death-starvation1 death-age1 death-epidemic1 death-accident1 death-disease1 death-child1 
          children-poor-people children-rich-people fertility-poor-people fertility-rich-people
          gini-base-line
          
          
          wealth-top wealth-mid wealth-low       ; this tracks the wealth splits for graphing purposes as defined by the user
          poplow popmid poptop                   ; this tracks the population in each wealth split.
          
          graphing-interval-last graphing        ; these variables control how often the graphs plot.
          max-cap max-cap1
          
          ]
          
breed [ people ] 
breed [ ghost ] 

patches-own
[ renewable-resource-here  ; how much 'needs' available on this patch
  harvest-cost             ; how much resistance covers this 'need'
  harvest-cost-original    ; memory of the initial setting
  
  fixed-resources-here     ; amount of 'wants' available on this patch
  fixed-resources-original ; memory of the amount of 'wants'
  extraction-cost          ; how much resistance covers this 'want'
  extraction-orginal       ; memory of original resistance
   
  resource-value           ; test for harvesting 'needs' (used for 'vision')
  extraction-value         ; test for harvesting 'wants'
  
  land-usage               ; used to calculate 'population'
  
  recovery                 ; how quickly this patch recovers if 'polluted'
  recovery1                ; recovery from overharvesting.

  land-disruption          ; used to calculate 'pollution'
  land-disruption1         ; used to calculate the effects of 'over harvesting'
  needs-harvest            ; total patch needs harvest over one iteration
  wants-harvest-indicator  ; indicates whether an agent has been harvesting 'wants' from this patch
  
]
 
people-own
[ age              ; how many iterations the agent has existed (based on reproductive capability, roughly analogous to years)
  needs            ; store of needs
  wants            ; store of wants
  income           ; income this iteration
  last-income-needs; last income of 'needs'
  last-income-wants; last income of 'wants'
  wander           ; used to control movement
  movement         ; evolutionary propensity for movement if need income levels drop
  movement-wants   ; evolutionary propensity for movement if want income is zero
  exploration      ; evolutionary propensity for exploration
  fertile          ; evolutionary variable controlling the likelihood of reproducing

  nurture-needs
  nurture-wants    ; evolutionary: how much they give to their child
  nurture-money

  child-need-buffer; evolutionary - controls how much 'need' an agent needs before reproducing. 
                   ; This is a key element to system starvation. The user can over-ride this evolutionary variable by using the Need-Birth-Buffer slider.
  
  children         ; how many children and agent has had
  peak-income      ; tracks peak-income for as long as the agent hasn't moved
  money            ; how money they have
  money-available  ; tracks how much money and agent has to give to their children
  money-value      ; the level of money below which the agent starts adjust prices to hold onto money
  mutation         ; evolutionary - the mutation of their evolutionary factors
  vision           ; evoluitonary - tracks how many patches ahead an agent can sense their environment
  labour           ; used to track how much 'labour' an agent can express in their environment
  
  price-up         ; evolutionary - tracks how much to an agent will change its price for trading purposes when triggered to do so 
  price-down
  
  needs-offered    ; tracks excess 'wants' and 'needs' used for trading
  wants-offered
  
  savings-rate-needs     ; evolutionary - how much an agent will hold in reserve before trading
  savings-wants

  buy-price-needs        ; the maximum an agent will pay when trading for goods - influenced by market - 
  buy-price-wants
  
  sell-price-needs       ; the minimum an agent will pay when selling - influenced by market -
  sell-price-wants
  
  price-factor-needs     ; used to execute a trade
  price-factor-wants
  
  propensity-labour      ; evolutionary - used to calculate of how 'wants' are utilised in empowering the agent
  propensity-health
  propensity-use-needs
  
  migration              ; evolutionary - allows the agent to evolve a propensity for using 'wants' to move.
  
  genetic-marker-kids    ; tracks inheritance so that a random child inherits their parent's wealth.
  genetic-marker-parent
  
  industrial-innovate    ; used to determine whether an agent can behave as a hunter/gather, trader, innovator (renewable technology), industrialist (non-renewable technology).
  class-ranking          ; tracks rank by wealth

  total-wealth           ; this calculates an agent's total wealth as proportionately set by the user.

  order-of-trade         ; evolutionary - the order in which an agent will conduct its trade and harvesting activities (cultures as defined by agency)
    
  charity                ; evolutionary - determines the amount of charity an agent will give if triggered into charity
  beg                    ; determines whether an agent will 'beg' or not.
  
  market                 ; determines an agent's trading reach. (ie other agents within 1 patch or other agents within 5 patches, etc.)
  
  needs-stock            ; determines how much needs an agent requires before it is comfortable aggregating non-renewable goods.
  exploring
  ]


to setup
  ;; (for this model to work with NetLogo's new plotting features,
  ;; __clear-all-and-reset-ticks should be replaced with clear-all at
  ;; the beginning of your setup procedure and reset-ticks at the end
  ;; of the procedure.)
  clear-all
  set max-renewable-resources-memory max-renewable-resources   ; these 'memory' variables keep track of the initial settings for the patches,
  set harshness-memory renewable-harshness
  If agent-seed > 0 [ random-seed agent-seed ]
  setup-people
  if environment-seed > 0 [ random-seed environment-seed ]
  setup-patch-renewables
  setup-patch-non-renewables
  set totalpop count people
  set auto-advance false                                       ; auto advance is a user switch that automatically advances the economic knowledge of the agents
                                                               ; meaning that it increases 'industrial-innovate' for the agents.
  ifelse sum [industrial-innovate] of people = 0 [ set trading-setting 0] 
                                                 [ set trading-setting 1
                                                   setup-trading ]
  set pop-peak-stop false                                       ; this automatically stops the simulation if the population falls below 15% of the beginning.
  set peak-population 0
  set trade-minimum 1 * 10 ^ -5                                ; this stops the simulation from dividing by zero
  set graphing-interval-last graphing-interval                 ; this helps control the graphing intervals.
  if manual-seed-switch = true [ random-seed manual-seed ]
                                 ; set manual-seed-switch false ]
  reset-ticks
end


to setup-people
  set-default-shape turtles "person"
  create-people num-people [                               ; creates and randomly places the people
    move-to one-of patches
    set size .8
    set age random Old-Age                                 ; sets random age
    set needs living-cost * 10                             ; sets the person's initial stock of needs ... gives an agent a five iteration head start.
    set fertile 1 + random Fertility-range                  
    set movement random 200
    set movement-wants random 200
    set exploration random 200
    set nurture-needs random-float 1
    set nurture-money .5                                   ; this prevents evolutionary selection in other areas from creating an extreme situation in this area before money is used.
    set order-of-trade 13                                  ; this prevents charting before trading occurs.
    set mutation random 200                               
    set vision random-float 3
    set labour starting-labour                             ; this is allows the system to remember the initial labour setting.
    ifelse NBB_evolve = true
     [ set child-need-buffer random-float need-birth-buffer ]
     [ set child-need-buffer need-birth-buffer ]

    
    set savings-rate-needs .7 + random-float 1

    set money-value money-supply / 4 + random-float money-supply / 4
       
    set genetic-marker-parent random-float 1000                 ; this controls inheritance.
    set industrial-innovate 0

    set charity random-float (charity-strength / 10)            ; charity-strength is a user adjustable slider. 
  ]
    set gini-base-line 0
end
  

; This sets up the agent for trade.

 to setup-trading
  set trading-setting 1
  ask people [
    
    set money money-supply
    set nurture-wants random-float 1                           ; determines what percentage of 'wants' does the parent give the child
    set nurture-money random-float 1                           ; determines what percentage of 'money' does the parent give the child
    set savings-wants random-float 1
    set savings-rate-needs savings-rate-needs + random-float 1 - random-float 1  ; determines how much 'need' an agent will hold onto before trading as a percentable of 'living-cost'.
    if savings-rate-needs < 0 [set savings-rate-needs 0]

    set migration random 100 / 100                             ; the next six sets the initial trading prices when the economy is turned on.
    set sell-price-needs starting-prices
    set sell-price-wants starting-prices
    set buy-price-needs starting-prices
    set buy-price-wants starting-prices
    set needs-pricing1 starting-prices
    set wants-pricing1 starting-prices
    set price-up  .001 + random-float .1                      ; sets the initial rate of price change and agent will use.
    set price-down .001 + random-float .1
    set order-of-trade random 12                                 ; this determines the order of trade for an agent.
    set propensity-labour 1 + random 100                         ; the 'propensity' variables control how much of an agent's 'wants' are used for each of these three possibilities.
    set propensity-health 1 + random 100
    let propensity-capital 1 + random 100                        ; This is meant to simulate capital accumulation. It is the portion of 'wants' not used.
    let all propensity-labour + propensity-health + propensity-capital
               set propensity-labour propensity-labour / all
               set propensity-health propensity-health / all
        
    set propensity-use-needs random-float 1                      ; this determines how much 'needs' will be converted to 'wants' in renewable economic activity.

   
 
    ifelse ( child-need-buffer * living-cost ) > ( living-cost * savings-rate-needs )
        [ set needs-stock random (( child-need-buffer * living-cost ) - ( living-cost * savings-rate-needs )) + living-cost ]
        [ set needs-stock random ( 2 * living-cost * savings-rate-needs ) ]
    
   
   ]
  
   
   
 end
   

to setup-patch-renewables
  
  ask patches
    [ set renewable-resource-here random max-renewable-resources                 ; max-renewable-resources is a user adjustable slider
      set harvest-cost 1 + land-usage + random-float renewable-harshness         ; renewable-harshness is a user adjustable slider. Land-usage will only be > 0 only if the simulations has been running.
      set recovery1 0
      set land-disruption1 0
      if over-harvest [ set land-disruption1 1 - random-float (eco-sensitivity * .001 )
                        set needs-harvest 0 
                        ifelse eco-recovery1 = 0 [ set recovery1 0 ]
                                                 [ set recovery1 random-float (2 ^ Eco-recovery1) / (Eco-recovery1 * max-renewable-resources ) ]
                        ]]
    
  if over-harvest [ repeat (count patches * .1) [ ask one-of patches [ set land-disruption1 1 - random-float .0001 ]]]
   
  repeat Ex-Harshness-Amount
         [ ask one-of patches [set harvest-cost harvest-cost * 10 ^ extraordinary-harshness]]   ; this creates the areas where agents normally cannot live.
                                                                                                ; Ex-Harshness-Amount and extraordinary-harshness are user adjustable sliders
  
  ask patches [set harvest-cost (sum [ harvest-cost ] of patches in-radius 1) / 9]      ; this smooths out the renewable environment
  
  repeat renewable-soft-patch
         [ ask one-of patches [ set harvest-cost 1 + random starting-labour ]]          ; this creates patches with low harvest resistance. 
                                                                                        ; renewable-soft-patch amd starting-labour are user adjustable sliders
  
   ask patches [ set harvest-cost-original harvest-cost                                 ; this creates a memory of the initial set-up
                    colour-patch ]
                                                         
end


to setup-patch-non-renewables

  ask patches [
      set fixed-resources-here random (10 ^ max-fixed-resources)                         ; max-fixed-resources is a user adjustable slider
      set fixed-resources-original fixed-resources-here                                  ; this creates a memory of the setup
      set extraction-cost 1 + random-float fixed-harshness                               ; fixed-harshness is a user adjustanble slider
      
      set recovery 0                                                                     ; this variable determines how quickly a patch recovers from disruption
      set land-disruption 0                                                              ; this variable determines how much a patch will be disrupted by harvesting non-renewables
      
      if pollution [
        ifelse eco-recovery = 0 [ set recovery 0 ]
                                [ set recovery random-float (2 ^ Eco-recovery) * (10 ^ (max-fixed-resources - 8)) ]          ; second bracket keeps eco-recovery in line with max resources. Eco-recovery is a user adjustable slider.
        set land-disruption (.0001 + random-float .001) * (2 ^ impact-weight)]
      colour-patch]
      
      repeat fixed-soft-patch                                                            ; this creates patches with low harvest resistance. 
         [ ask one-of patches [ set extraction-cost 1 + random starting-labour ]]        ; fixed-soft-patch and starting-labour are user adjustable sliders
      

end      

; This colours patches by how much renewables resources there are divided by the resistance. The bigger the ratio, the darker the patch.

to colour-patch         
  set pcolor scale-color lime (renewable-resource-here / harvest-cost / 4)  30  -10
  if harvest-cost-original > 1.5 * harshness-memory [ set pcolor scale-color sky (renewable-resource-here / harvest-cost / 4)  30  -10 ]

end

; This colours patches according to how much 'land-usage' (pollution that increases renewable harvest resistence) is being carried by the patch.

to extract-colour
  set pcolor scale-color grey (land-usage / (10 ^ (max-fixed-resources - 4))) 10 0
  if harvest-cost-original > 1.5 * harshness-memory [ set pcolor scale-color orange (land-usage / (10 ^ (max-fixed-resources - 4)))  10 0 ]
end


to go
  
  tick
;  if max-cap1 > 0 [ set max-cap 0
;                    set max-cap1 0
;                    stop ]
  if ticks > 1700 and top-pop-stop = true and totalpop >= toppop [ stop]
  if trading-setting = 0 [if sum [ industrial-innovate ] of people > 0 [ setup-trading ]]  ; if the simulator is running in 'hunter/gatherer' mode, it doesn't setup for trading.
  set max-price-needs 1000000 * max [ buy-price-needs ] of people                             ; these prevents trading if an agent has nothing to trade
  set max-price-wants 1000000 * max [ buy-price-wants ] of people
  if contamination > 0 [ diffuse land-usage 10 ^ ( Contamination - 5 ) ]                   ; contamination is a user adjustable slider. This controls how a polluted patch influences its neighbours
  ask patches [ set wants-harvest-indicator 0
                if over-harvest and needs-harvest > 0
                  [ if needs-harvest > renewable-resource-here * land-disruption1          ; This creates more resistance to harvesting 'needs' if a patch is overharvested.
                     [ set land-usage land-usage + (needs-harvest - ( renewable-resource-here * land-disruption1 )) * .002 * eco-decline
                       set needs-harvest 0 ]]
                
                if land-usage > 0 [ set land-usage land-usage - recovery - recovery1       ; land-usage is the simulation of 'pollution'.
                                    if land-usage <= 0 [set land-usage 0
                                                       colour-patch ]
                                    set harvest-cost harvest-cost-original + land-usage    ; the effect of 'pollution' is to increase the harvest cost of 'needs' 
                                    if land-usage > 0 [ extract-colour ]]
                set resource-value (renewable-resource-here - (living-cost * (count people-here with [ age > child-dependency ] + 1))) * ((sum [labour ] of people-here with [ age > child-dependency ] + 1) / harvest-cost)
                                                                                           ; this is one of the variables 'vision' uses to determine the 'worth' of a patch.
                                                                                           ; child-dependency and living-cost are user adjustable sliders.
                
                ifelse fixed-resources-here > 0
                  [ set extraction-value sum [ labour ] of people-here - extraction-cost ] ; this is the other variable 'vision' uses.
                  [ set extraction-value (- 1000000) ]
       
              ]
  if auto-turnon = ticks [ set auto-advance true ]                                         ; auto-turnon is a user adjustable slider. auto-advance is a user switch.
  if auto-shutoff > 0 [ if count people with [industrial-innovate = 3 ] >= auto-shutoff [ set auto-advance false ]]     ; auto-shutoff is a user adjustable slider.
  set plague random ( 20000  -  count people - (40 * epidemics)) + random 15 + 1           ; epidemics is a user adjustable slider. The second random normally prevents total population loss.
                                                                                           ; this equation is the result of countless revisions. It works so it has not been changed.
               
  ask people with [ age >= child-dependency ]                                              ; child-dependency is a user adjustable slider.
               [               
               if NBB_Evolve = false [ set child-need-buffer need-birth-buffer ]
               ifelse industrial-innovate = 0 [ set needs-offered needs - living-cost      ; do we have 'needs' to trade?
                                                if needs-offered < 0 [set needs-offered 0]
                                                find-food ]                                ; subroutine to harvest 'needs'
               [
               
               set market 1 + sqrt (wants)                                                 ; this sets the range of an agents ability to see trades over a distance. 
               if market > max-market-vision and max-market-vision > 0 [ set market max-market-vision ]              ; max-market-vision is a user adjustable slider

               set wants wants - ((propensity-labour + propensity-health) * wants * (1 / (2 ^ recycling)))  ; this decreases the 'wants' by the amount 'wants' is being used.
                                                                                                            ; recycling is a user adjustable slider

               if auto-naturalisation > 0 [ if random ((2 ^ (20 - auto-naturalisation)) * 10000 * (income + last-income-needs + last-income-wants)) < mutation
                                                                     [ set industrial-innovate random industrial-innovate
                                                                       if wants > 0 and industrial-innovate < 2 [ 
                                                                          ifelse max [industrial-innovate] of people < 2 
                                                                              [ set wants 0 ]
                                                                              [ let found-wants wants * ( .85 + random-float .15)          ; This simulates material degradation.
                                                                                set wants 0
                                                                                Ask min-one-of other people with [ industrial-innovate > 1 ] [ distance myself ] [ set wants wants + found-wants ]]]]]
                                    ; auto-naturalisation is a user adjustable slider that gives the agents the ability to regress to previous levels of industrial-innovate

               prepare-trade
               
                if industrial-innovate > 0 [ 
                 if money < money-value [ buy-price-needs-down
                                          sell-price-needs-up
                                          if industrial-innovate > 1 
                                          [ buy-price-wants-down 
                                            sell-price-wants-up ]]
                 if wants < savings-wants and industrial-innovate > 1 [ sell-price-wants-up
                                                                        buy-price-wants-down ]
                                       ; These are the trading instructions. Each agent will execute one depending on the value of their variable order-of-trade.
                 if order-of-trade = 0 [order-0]                                           ; This code was implemented because I was trying to decide how the order might effect the simulation and then decided to let the simulation decide which order was best.
                 if order-of-trade = 1 [order-1]                                           ; This allows trading cultures to emerge. It is interesting that in well tuned simulations, during the technological boom, one culture tends to dominate the system.
                 if order-of-trade = 2 [order-2]
                 if order-of-trade = 3 [order-3]
                 if order-of-trade = 4 [order-4]
                 if order-of-trade = 5 [order-5]
                 if order-of-trade = 6 [order-6]
                 if order-of-trade = 7 [order-7]
                 if order-of-trade = 8 [order-8]
                 if order-of-trade = 9 [order-9]
                 if order-of-trade = 10 [order-10]
                 if order-of-trade = 11 [order-11]
                 ]]
              
               explore                                                                     ; this is allows an agent to explore
               set needs needs - living-cost                                               ; this is the basic survival constraint. Living-cost is a user adjustable slider.
               
              
               
               
               if charity-strength > 0 [ ifelse needs < giving-threshold * living-cost [ if any? other people-here [ set beg 1 
                                                                                                                     set beggers beggers + 1 ]]
                                                                                       [ do-charity ]]
               
                                                                                           ; the previous code allows agents to give to other needy agents or ask for help if they need it.
            
               age-die                                                                     ; this tests for all the diseases and ages the agent. It also tests of reproduction.
               
               if Culture-Transfer > 0 [ if random ((101 - Culture-Transfer * 2000)) < mutation 
                      [ if max [ total-wealth ] of people-here > [ total-wealth ] of self [ Cultural-transfer ]]]
               
               if Knowledge-Transfer > 0 [ If industrial-innovate < 3 and [ wants-harvest-indicator ] of patch-here = 1 
                                              [ if random ((101 - Knowledge-Transfer) * 2000) < mutation [ set industrial-innovate 3 ]]]
               
                 ]
               
               
                 
  if child-dependency > 0                                                                  ; this creates needy children that parents must feed. Child-dependency is a user adjusable slider.           
      [ask people with [ age < child-dependency ] 
              [ set needs needs - (living-cost * age / child-dependency)
                if needs < living-cost * age / child-dependency
                [ if count people with [ genetic-marker-parent = [genetic-marker-kids] of self] > 0
                  [ let my-needs (living-cost - needs)   
                    ask one-of people with [ genetic-marker-parent = [genetic-marker-kids] of self ]
                                    [ ifelse needs - living-cost > my-needs
                                         [ set needs needs - my-needs 
                                           ask self [ set needs needs + my-needs ]]
                                         [ let low-needs 0
                                           if needs > living-cost [ set low-needs needs - living-cost ]
                                           set needs needs - low-needs
                                           ask self [ set needs needs + low-needs ]]]]]
     
               if charity-strength > 0 [ if needs < living-cost * age / child-dependency and count people-here > 1 [ if any? other people-here [set beg 1 
                                                                                                                        set beggers beggers + 1 ]]]
               age-die-child
               ]]            
  
 
  if count people < 2 [ set totalpop count people                   ; On population extinction, stopping the simulation before it crashes is difficult.
                          stop ]
  
  ask people with [industrial-innovate > 0 ][ set total-wealth (needs * needs-balancing) + (money * ((money-supply * count people) / sum [ money ] of people) * (money-balancing / 100)) + (wants * (wants-balancing / 5000)) ]
  ask people with [industrial-innovate = 0 ][ set total-wealth (needs * needs-balancing)]      ; these lines are for charting purposes. The 'balancing' variables are user adjustable sliders.
  
  if colour [ ask people [                                          ; colour is a user switch that shows which agents are operating under which economic instruction.
               if industrial-innovate = 0 [ set color green ]
               if industrial-innovate = 1 [ set color red ]
               if industrial-innovate = 2 [ set color yellow ] 
               if industrial-innovate = 3 [ set color violet ]]]
  
  
  
  if tax > 0 [ if sum [ needs ] of people with [ age > 11 ] > 0 [   ; this routine is to tax agents in the event 'child-benefits' is turned on by the user.
               let tax-burden tax / sum [ needs ] of people with [ age > 11 ]
               ask people with [ age > 16 ] [ set needs needs * (1 - tax-burden)
                                 if needs <= 0 [ set death-starvation death-starvation + 1
                                                 if age < Child-Dependency [ set death-child death-child + 1 ]
                                                 brown-bread ]] 
               set tax 0 ]]
  
  if count people < 2 [ set totalpop count people                   ; On population extinction, stopping the simulation before it crashes is difficult.
                        stop ]
  
  update-plot-variables
  set food-production 0
  set goods-production 0
  set death-rate 0
  set death-rate-adults 0
  set birth-rate 0
  set trade-needs 0
  set trade-wants 0
  set beggers 0
  set act-of-charity 0
  set ave-death-age 0
  set volume-wants 0
  set volume-needs 0
  set economy-wants 0
  set economy-needs 0
  
  ; auto-advance is a user switch. It allows the user to ask the simulation to determine when agents change economic instructions.
  
  if auto-advance    [ ask people with [ age >= child-dependency ] 
                         [ if industrial-innovate = 0 [ if random (10 ^ ( 13 - strength)) < mutation * ( total-wealth / 10 )     ; strength is a user adjustable slider.
                             [ set initial-wave 1
                               if industrial-innovate = 0 [ raise-to-trader ]]]
                           
                           if industrial-innovate = 1 [ if random (10 ^ ( 13 - strength)) < mutation * ( total-wealth / 20 )
                             [ set initial-wave 1
                               if industrial-innovate = 1 [ raise-to-renewable ]]]
                                                              
                           if industrial-innovate = 2 [ if random (10 ^ ( 13 - strength)) < mutation * ( total-wealth / 20 )
                           [ find-goods
                             if income > 0 [ set industrial-innovate 3 ]]]]]
  
  if ticks = start-trading [ initialise-trading ]                       ; These three variables are user adjustable sliders that allows the experimenter to run the simulation without watching over it.
  if ticks = start-renewable-economy [ initialise-renewable-economy ]
  if ticks = start-industrialisation [ industrialise ]
  
  if ticks = stop-simulation [ stop ]                                   ; stop-simulation is a user adjustable slider that allows the experimenter to have the simulation automatically stop on a particular iteration.
  if pop-peak-stop [if totalpop / peak-population < .15 [ set pop-peak-stop false     ; pop-peak-stop is a user switch that will automatically stop the simulation if the population drops to 15% of its peak.
                                                          stop ]]
  if ticks <= start-graphs [ set peak-population 0 ]                    ; start-graphs is a user adjustable slider.
  ask people [set beg 0]                                                ; This resets the agents' charity variable.
  
end


; this subroutine ensures the key trading variables are up to date before trading is initiated.

to prepare-trade
                       
          set needs-offered needs - (savings-rate-needs * living-cost)
          set wants-offered wants
          if age < child-dependency [ set needs-offered 0
                                      set wants-offered 0 ]
               

          ifelse needs-offered <= .01 [ set price-factor-needs max-price-needs ]          ; This creates a minimum trade quantity. 'Max-price-needs' prevents trading.
                                      [ set price-factor-needs sell-price-needs ]
          
          ifelse wants <= trade-minimum
                                      [ set price-factor-wants max-price-wants ]                     
                                      [ set price-factor-wants sell-price-wants ]

end


; initial-wave1 is a user adjustable slider used to force a user set number of agents to become 'traders'.
; Traders can trade 'needs' for 'money'.

to initialise-trading
   ifelse initial-wave1 < count people [ set initial-wave initial-wave1 
                                         raise-to-trader ]
                                       [ ask people [ set industrial-innovate 1 ]]
end

; this routine changes the agent variable industrial-innovate to 1. It is separated from the above routine so that it can be used by the programme in different ways.
; Changes for the other two conditions (industrial-innovate = 2 or 3) follow this same pattern in the coding below.

to raise-to-trader

   ifelse initial-wave <= count people with [ needs-offered > 0 ]
     [ repeat initial-wave [ ask one-of people with [ needs-offered > 0 ] [ set industrial-innovate 1 ]]]
     [ repeat initial-wave [ ask one-of people [ set industrial-innovate 1 ]]]
end


; initial-wave2 is a user adjustable slider used to force a user set number of agents to become 'innovators'. 
;'Innovators' can convert 'needs' into 'wants' and trade each for 'money'.

to initialise-renewable-economy

   ifelse initial-wave2 < count people [ set initial-wave initial-wave2 
                                         raise-to-renewable ]
                                       [ ask people [ set industrial-innovate 2 ]] 
end

to raise-to-renewable

   ifelse initial-wave <= count people with [ industrial-innovate = 1 and needs-offered > 0 ]
     [ repeat initial-wave [ ask one-of people with [ industrial-innovate = 1 and needs-offered > 0 ] [ set industrial-innovate 2 ]]]
     [ ifelse initial-wave <= count people with [ industrial-innovate = 1 ]
       [ repeat initial-wave [ ask one-of people with [ industrial-innovate = 1 ] [ set industrial-innovate 2 ]]]
       [ repeat initial-wave [ ask one-of people [ set industrial-innovate 2 ]]]]

end

; initial-wave3 is a user adjustable slider used to force a user set number of agents to become 'industrialists'. 
;'Industrialists' can harvest 'wants' from the environment and trade for 'money'. 

to industrialise

   ifelse initial-wave3 < count people [ set initial-wave initial-wave3 
                                         raise-to-industrialist ]
                                       [ ask people [ set industrial-innovate 3 ]]
end

to raise-to-industrialist

   ifelse initial-wave <= count people with [ industrial-innovate = 2 and wants > 0 ]
     [ repeat initial-wave [ask one-of people with [ industrial-innovate = 2 and wants > 0 ] [ set industrial-innovate 3
                                                                                               set order-of-trade random 6 ]]]
     [ ifelse initial-wave <= count people with [ industrial-innovate = 2 ]
       [ repeat initial-wave [ ask one-of people with [ industrial-innovate = 2 ] [ set industrial-innovate 3
                                                                                    set order-of-trade random 6 ]]]
       [ repeat initial-wave [ ask one-of people [ set industrial-innovate 3
                                                   set order-of-trade random 6 ]]]]

end

; the following 'Orders' are all the different orders of trade and harvesting available to the agents in this simulation.
; find-food is the 'needs' harvesting routine and find-goods is the 'wants' harvesting routine.
; the conditions also change (ie. 'if needs-offered < 0 [ find-food ]' as opposed to 'if needs-offered < 0 or wants-offered > 0 [find-food]')



to Order-0
               ifelse needs < needs-stock or industrial-innovate < 3 [ find-food ]                                             
                                                                   [ find-goods ]
               if any? other people in-radius market [
                 if money > trade-minimum [ buy-needs ]                      ; trade-minimum is a programmed minimum unit that helps prevent trading tiny quantities which can lead to a division by 0.
                 if money > trade-minimum [ buy-needs ]  
                 if money > trade-minimum [ buy-wants ]
                 if money > trade-minimum [ buy-wants ]
                 if needs-offered > trade-minimum [ sell-needs ]
                 if needs-offered > trade-minimum [ sell-needs ]
                 if wants-offered > trade-minimum [ sell-wants ]
                 if wants-offered > trade-minimum [ sell-wants ]]
                 
end
                 
to Order-1                                                                                                           
               if any? other people in-radius market [
                 if money > trade-minimum [ buy-needs ]
                 if money > trade-minimum [ buy-needs ]    
                 if money > trade-minimum [ buy-wants ]
                 if money > trade-minimum [ buy-wants ]
                 if needs-offered > trade-minimum [ sell-needs ]
                 if needs-offered > trade-minimum [ sell-needs ]
                 if wants-offered > trade-minimum [ sell-wants ]
                 if wants-offered > trade-minimum [ sell-wants ]]
               ifelse needs < needs-stock or industrial-innovate < 3 [ find-food ]
                                                                   [ find-goods ]
end

to order-2                                                                                                                 
               if any? other people in-radius market [
                 if needs-offered > trade-minimum [ sell-needs ]
                 if needs-offered > trade-minimum [ sell-needs ]
                 if wants-offered > trade-minimum [ sell-wants ]
                 if wants-offered > trade-minimum [ sell-wants ]
                 if money > trade-minimum [ buy-needs ]
                 if money > trade-minimum [ buy-needs ]
                 if money > trade-minimum [ buy-wants ]
                 if money > trade-minimum [ buy-wants ]
                 ]
               ifelse needs < needs-stock or industrial-innovate < 3 [ find-food ]
                                                                   [ find-goods ]
end

to order-3
               ifelse needs < needs-stock or industrial-innovate < 3 [ find-food ]
                                                                   [ find-goods ]                                                                                          
               if any? other people in-radius market [
                 if needs-offered > trade-minimum [ sell-needs ]
                 if needs-offered > trade-minimum [ sell-needs ]
                 if wants-offered > trade-minimum [ sell-wants ]
                 if wants-offered > trade-minimum [ sell-wants ]
                 if money > trade-minimum [ buy-needs ]
                 if money > trade-minimum [ buy-needs ]
                 if money > trade-minimum [ buy-wants ]
                 if money > trade-minimum [ buy-wants ]
                 ]
end

to Order-4                                                                                                        
              if any? other people in-radius market [
                 if money > trade-minimum [ buy-needs ]
                 if money > trade-minimum [ buy-needs ]
                 if money > trade-minimum [ buy-wants ]
                 if money > trade-minimum [ buy-wants ]]
              ifelse needs < needs-stock or industrial-innovate < 3 [ find-food ]
                                                                  [ find-goods ]
              if any? other people in-radius market [   
                 if needs-offered > trade-minimum [ sell-needs ]
                 if needs-offered > trade-minimum [ sell-needs ]
                 if wants-offered > trade-minimum [ sell-wants ]
                 if wants-offered > trade-minimum [ sell-wants ]]
end

to Order-5                                                                                                           
              if any? other people in-radius market [
                 if needs-offered > trade-minimum [ sell-needs ]
                 if needs-offered > trade-minimum [ sell-needs ]
                 if wants-offered > trade-minimum [ sell-wants ]
                 if wants-offered > trade-minimum [ sell-wants ]]
              ifelse needs < needs-stock or industrial-innovate < 3 [ find-food ]
                                                                  [ find-goods ]
              if any? other people in-radius market [   
                 if money > trade-minimum [ buy-needs ]
                 if money > trade-minimum [ buy-needs ]
                 if money > trade-minimum [ buy-wants ]
                 if money > trade-minimum [ buy-wants ]]
end

to Order-6                                                                                                           
               if any? other people in-radius market [
                 if money > trade-minimum [ buy-needs ]
                 if money > trade-minimum [ buy-needs ]
                 if money > trade-minimum [ buy-wants ]
                 if money > trade-minimum [ buy-wants ]
                 if needs-offered > trade-minimum [ sell-needs ]
                 if needs-offered > trade-minimum [ sell-needs ]
                 if wants-offered > trade-minimum [ sell-wants ]
                 if wants-offered > trade-minimum [ sell-wants ]]
               ifelse needs < needs-stock or industrial-innovate < 3 or wants-offered > 0 [ find-food ]
                                                                                        [ find-goods ]
end

to order-7                                                                                                                 
               if any? other people in-radius market [
                 if needs-offered > trade-minimum [ sell-needs ]
                 if needs-offered > trade-minimum [ sell-needs ]
                 if wants-offered > trade-minimum [ sell-wants ]
                 if wants-offered > trade-minimum [ sell-wants ]
                 if money > trade-minimum [ buy-needs ]
                 if money > trade-minimum [ buy-needs ]
                 if money > trade-minimum [ buy-wants ]
                 if money > trade-minimum [ buy-wants ]
                 ]
              
               ifelse needs < needs-stock or industrial-innovate < 3 or wants-offered > 0 [ find-food ]
                                                                                        [ find-goods ]
end

to order-8
               ifelse needs < needs-stock or industrial-innovate < 3 or wants-offered > 0 [ find-food ]
                                                                                        [ find-goods ]
               if any? other people in-radius market [
                 if needs-offered > trade-minimum [ sell-needs ]
                 if needs-offered > trade-minimum [ sell-needs ]
                 if wants-offered > trade-minimum [ sell-wants ]
                 if wants-offered > trade-minimum [ sell-wants ]
                 if money > trade-minimum [ buy-needs ]
                 if money > trade-minimum [ buy-needs ]
                 if money > trade-minimum [ buy-wants ]
                 if money > trade-minimum [ buy-wants ]
                 ]
end

to Order-9                                                                                                        
              if any? other people in-radius market [
                 if money > trade-minimum [ buy-needs ]
                 if money > trade-minimum [ buy-needs ]
                 if money > trade-minimum [ buy-wants ]
                 if money > trade-minimum [ buy-wants ]]
              ifelse needs < needs-stock or industrial-innovate < 3 or wants-offered > 0 [ find-food ]
                                                                                       [ find-goods ]
              if any? other people in-radius market [   
                 if needs-offered > trade-minimum [ sell-needs ]
                 if needs-offered > trade-minimum [ sell-needs ]
                 if wants-offered > trade-minimum [ sell-wants ]
                 if wants-offered > trade-minimum [ sell-wants ]]
end

to Order-10                                                                                                           
              if any? other people in-radius market [
                 if needs-offered > trade-minimum [ sell-needs ]
                 if needs-offered > trade-minimum [ sell-needs ]
                 if wants-offered > trade-minimum [ sell-wants ]
                 if wants-offered > trade-minimum [ sell-wants ]]
              ifelse needs < needs-stock or industrial-innovate < 3 or wants-offered > 0 [ find-food ]
                                                                                       [ find-goods ]
              if any? other people in-radius market [   
                 if money > trade-minimum [ buy-needs ]
                 if money > trade-minimum [ buy-needs ]
                 if money > trade-minimum [ buy-wants ]
                 if money > trade-minimum [ buy-wants ]]
end

to Order-11
               ifelse needs < needs-stock or industrial-innovate < 3 or wants-offered > 0 [ find-food ]
                                                                                        [ find-goods ]
               prepare-trade
               if any? other people in-radius market [
                 if money > trade-minimum [ buy-needs ]
                 if money > trade-minimum [ buy-needs ]  
                 if money > trade-minimum [ buy-wants ]
                 if money > trade-minimum [ buy-wants ]
                 if needs-offered > trade-minimum [ sell-needs ]
                 if needs-offered > trade-minimum [ sell-needs ]
                 if wants-offered > trade-minimum [ sell-wants ]
                 if wants-offered > trade-minimum [ sell-wants ]]

end



; this harvests 'needs'

to find-food
  
 if needs-stock < needs and industrial-innovate = 2          ; if an agent is using a 'renewable economy' then convert 'needs' into 'wants' (eg traditional bow and arrow)
                                    [ let ns needs - needs-stock
                                      set wants wants + (ns * propensity-use-needs * renewable-economy)     ; propensity-use-needs is an agent evolutionary variable.
                                                                                                               ; renewable-economy is a user adjustable slider controlling the 'strength' of the renewable technology
                                      let needs-used ns * propensity-use-needs
                                      set needs needs - needs-used
                                      set needs-offered needs-offered - needs-used ]
  
  ; child-dependency is a user adjustable slider. If it is greater than 0 this routine sets the 'labour' which is the agent's harvesting power.
               
  if age >= child-dependency [ set labour starting-labour + (propensity-labour * wants * industrial-efficiency)]
  
  let everyones-labour sum [labour] of people-here ; this is a simulation assumption for the sake of simplicity (others have been experimented with). It sums all the agents labour on the patch for the purposes of harvesting, regardless if they end up harvesting 'needs' or 'wants'.
                                                   ; it also creates an automatic wastefulness in the harvesting of 'needs' as the harvesting of 'wants' increases.
  ifelse everyones-labour - harvest-cost < 0       ; if everyone's labour can't overcome the resistance, then there is no harvest
    [ set income 0 
      if last-income-needs < living-cost                  ; if this income and the last income was 0, it is time to consider another patch.
      [ if random movement = 0 or exploring = 1 [ set wander 1      ; 'movement' is an evolutionary variable. 'wander' is used to determine which kind of movement occurs in the 'move' subroutine
                                 set exploring 1
                                 move ]]]
    [ set exploring 0 
      ifelse everyones-labour > renewable-resource-here
        [ set income renewable-resource-here * (labour / everyones-labour) ]         ; this set an agent's income in proportion to their labour in relation to all the labour present.
        [ set income labour - (harvest-cost * (labour / everyones-labour)) ]]
  set needs needs + income
  set needs-harvest needs-harvest + income              
  set food-production food-production + income                                       ; this is for graphing purposes
  set last-income-needs income                                                       ; this remembers harvesting income
  prepare-trade                                                                      ; this updates the key trading variables

end

; this harvests 'wants'. It follows the same pattern as the previous routine. There is no test for industrial-innovate = 2 because only industrial-innovate = 3 can use this routine.

to find-goods
               
 if fixed-resources-here = 0 [ set wander 3
                               move ]
 if age >= child-dependency [ set labour starting-labour + (propensity-labour * wants * industrial-efficiency)]
 
 set exploring 1
 let everyones-labour sum [ labour ] of people-here with [ industrial-innovate > 2 ]                              
 ifelse everyones-labour - extraction-cost <= 0 or fixed-resources-here <= 0
     [set income 0
      if last-income-wants = 0 [ if random movement-wants = 0 [ set wander 3 
                                                                move ]]]   
     [ let total-extraction (everyones-labour - extraction-cost) * (labour / everyones-labour)
      ifelse fixed-resources-here - total-extraction > 0
        [ set income total-extraction ]   
        [ set income fixed-resources-here ]
      set wants wants + income
      set goods-production goods-production + income
      let depletion income
      ask patch-here [ set fixed-resources-here fixed-resources-here - depletion            
                       set land-usage land-usage + (land-disruption * depletion)
                       set harvest-cost harvest-cost-original + land-usage 
                       set wants-harvest-indicator 1 ]]
      set last-income-wants income
      prepare-trade
end

; The following four subroutines control the buying and selling of 'wants' and 'needs'. They all follow the same pattern.
 
to buy-needs
   set money-offered money
   if any? other people in-radius market with [industrial-innovate > 0 and needs-offered > trade-minimum ]       ; Is anyone out there in a position to do business?
      [ ask min-one-of other people in-radius market with [ needs-offered > trade-minimum ] [ price-factor-needs ] ; Who has got the best price for me? 'Trade-minimum' is a single global varible in the setup that prevents the simulation from dividing by 0
        [ ifelse price-factor-needs <= [ buy-price-needs ] of self                                                ; Is your best price within my price range? If yes, let's trade! 'Price-factor-needs' is used to prevent the trading initiator from choosing the best price from an agent who has nothing to trade.
              [ set price-offered sell-price-needs
                if money-offered > needs-offered * sell-price-needs
                   [ set money-offered needs-offered * sell-price-needs ]                                         ; This code is does the trading mechanics. There are two possibilities: 1) if there is more money than the goods are worth then ...
                set goods-exchanged money-offered / sell-price-needs                                              ; This code is does the trading mechanics. There are two possibilities: ... and 2) if there is less money available than the goods are worth then ...
                set needs needs - goods-exchanged
                set money money + money-offered
                set economy-needs economy-needs + money-offered
                ask self [ set needs needs + goods-exchanged
                           set money money - money-offered
                           prepare-trade
                           set trade-needs trade-needs + 1
                           set volume-needs volume-needs + goods-exchanged
                           set buy-price-needs price-offered
                           if needs-offered > 0 [ buy-price-needs-down ]
                         ]
                if industrial-innovate = 0 [ set industrial-innovate 1 ]
                prepare-trade ]
          
              [ ask self [ buy-price-needs-up ]]]]                                ; If no ones' price is within my price range, perhaps I should lower my price expectations.
                
end

to buy-wants

     set money-offered money
     if any? other people in-radius market with [industrial-innovate > 0 and wants-offered > trade-minimum ]
      [ ask min-one-of other people in-radius market with [ wants-offered > trade-minimum ] [ price-factor-wants ] 
         [ ifelse price-factor-wants <= [ buy-price-wants ] of self
              [ set price-offered sell-price-wants
                if money-offered > wants-offered * sell-price-wants
                   [ set money-offered wants-offered * sell-price-wants ]  
                set goods-exchanged money-offered / sell-price-wants
                set money money + money-offered
                set wants wants - goods-exchanged
                set economy-wants economy-wants + money-offered
                ask self [ set wants wants + goods-exchanged
                           set money money - money-offered
                           prepare-trade
                           set trade-wants trade-wants + 1
                           set volume-wants volume-wants + goods-exchanged
                           set buy-price-wants price-offered
                           if wants-offered > 0 [ buy-price-wants-down ]
                          ]
                prepare-trade ]
           
              [ ask self [ buy-price-wants-up ]]]]
              
                
end

to sell-needs

    set goods-exchanged needs-offered 
    if any? other people in-radius market with [ industrial-innovate > 0 and money > trade-minimum ]
      [ ask max-one-of other people in-radius market with [ money > trade-minimum ] [ buy-price-needs ]
        [ ifelse buy-price-needs >= [ sell-price-needs ] of self
          [     if money < goods-exchanged * buy-price-needs
                   [ set goods-exchanged money / buy-price-needs ]            
                set money-offered goods-exchanged * buy-price-needs
                set needs needs + goods-exchanged
                set money money - money-offered
                set economy-needs economy-needs + money-offered
                ask self [ set needs needs - goods-exchanged
                           set money money + money-offered
                           prepare-trade
                           set trade-needs trade-needs + 1
                           set volume-needs volume-needs + goods-exchanged
                           if needs-offered < 0 [ sell-price-needs-up ]
                         ]
                prepare-trade ]
                
           [ ask self [ sell-price-needs-down ]]]]

end

to sell-wants


    set goods-exchanged wants-offered 
    if any? other people in-radius market with [ industrial-innovate > 0 and money > trade-minimum ]
      [ ask max-one-of other people in-radius market with [ money > trade-minimum ] [ buy-price-wants ]
        [ ifelse buy-price-wants >= [ sell-price-wants ] of self
          [     if money < goods-exchanged * buy-price-wants
                   [ set goods-exchanged money / buy-price-wants ]            
                set money-offered goods-exchanged * buy-price-wants
                set wants wants + goods-exchanged
                set money money - money-offered
                set economy-wants economy-wants + money-offered
                ask self [ set wants wants - goods-exchanged
                           set money money + money-offered
                           prepare-trade
                           set trade-wants trade-wants + 1
                           set volume-wants volume-wants + goods-exchanged
                           if wants-offered < 0 [ sell-price-wants-up ]
                         ]
                prepare-trade ]
                
           [ ask self [ sell-price-wants-down ]]]]
      

end




; the follwing eight subroutines raise and lower the agents' price expectations.

to buy-price-needs-down
      if buy-price-needs < min [ buy-price-needs ] of people [ stop ]
      set buy-price-needs buy-price-needs - ( buy-price-needs * price-down )
      if buy-price-needs <= 0 [ set buy-price-needs trade-minimum ]
end

to buy-price-needs-up
      if buy-price-needs > max [ buy-price-needs ] of people [ stop ]
      set buy-price-needs buy-price-needs + ( buy-price-needs * price-up )    
end

to buy-price-wants-down
     if buy-price-wants < min [ buy-price-wants ] of people [ stop ]
     set buy-price-wants buy-price-wants - ( buy-price-wants * price-down )
     if buy-price-wants <= 0 [ set buy-price-wants trade-minimum ]
end

to buy-price-wants-up
     if buy-price-wants > max [ buy-price-wants ] of people [ stop ]
     set buy-price-wants buy-price-wants + ( buy-price-wants * price-up )
end

to sell-price-needs-up
    if sell-price-needs > max [ sell-price-needs ] of people [ stop ]
    set sell-price-needs sell-price-needs + (sell-price-needs * price-up)
end

to sell-price-needs-down
    if sell-price-needs < min [ sell-price-needs ] of people [ stop ]
    set sell-price-needs sell-price-needs - (sell-price-needs * price-down)
    if sell-price-needs <= 0 [ set sell-price-needs trade-minimum ]
end

to sell-price-wants-up
    if sell-price-wants > max [ sell-price-wants ] of people [ stop ]
    set sell-price-wants sell-price-wants + (sell-price-wants * price-up)
end

to sell-price-wants-down
    if sell-price-wants < min [ sell-price-wants ] of people [ stop ]
    set sell-price-wants sell-price-wants - (sell-price-wants * price-down)
    if sell-price-wants <= 0 [ set sell-price-wants trade-minimum ]
end


; if the user set child-dependency > 0, this is the routine the 'child' uses to determine aging and death.

to age-die-child

       if child-benefit > 0 [ set tax tax + (living-cost * child-benefit)            ; child-benefit and living-cost are user adjustable slider.
                              set needs needs + (living-cost * child-benefit) ]
       if needs < 0 [ set death-starvation death-starvation + 1                      ; if 'needs' have dropped below 0, the agent will die. 
                      set death-child-dep death-child-dep + 1 
                      set wealthdeathno wealthdeathno + 1                                                               ; It is a matter of choice as to weather you want the death measured solely as child mortality or starvation or both. Right now it is set up for both for all these cases.. 
                      set death-child death-child + 1                               
                      brown-bread ]                                                  ; brown-bread is the death subroutine
       set age age + 1                                                               ; if the agent doesn't die, it gets another birthday!
       if age = child-dependency [ set money money + money-available                 ; 'money-available' stores money given to it by its parent at birth until it is old enough to spend it.
                                   set money-available 0 ]
       if random-float epidemics - random-float ((needs * natural-medical) + sqrt (sqrt ((propensity-health * wants * tech-medical)))) >= plague 
                                                                                     ; 'epidemics', 'natural-medical', 'propensity-health', and 'tech-medical' are user adjustable sliders.
                                                                                     ; 'plague' is a global random variable. The '*-medical' variables increase the probability of survival
                                                                                     ; 'propensity-health' is how much an agent is willing to 'spend' on medicine.

          [ set death-epidemic death-epidemic + 1                  
            set death-child death-child + 1
            brown-bread ]
       if accidents > 0 and random (300 - accidents) = 0           ; accidents is a user adjustable slider. This is meant to simulate random acts of death. 
          [ set death-accident death-accident + 1
            set death-child death-child + 1
            brown-bread ]
       if disease > 0 [ if random (250 - Disease + (needs * natural-medical) + sqrt ((propensity-health * wants * tech-medical))) - random (land-usage * toxicity) <= 0 
                                                                   ; 'disease' is a user adjustable slider
                                                                   ; disease, natural-medical, propensity-health, toxicity, and tech-medical are user adjustable sliders.
                                                                   ; This works the same way as 'epidemics' except the user can also add 'pollution' as a cause of death through the 'toxicity' slider.
            [ set death-child death-child + 1
              set death-disease death-disease + 1
              brown-bread ]]
       if age < 5 and infantmort > 0 [ if random (20 - infantmort + sqrt (propensity-health * wants * tech-medical) + (needs * natural-medical)) - random (land-usage * toxicity) <= 0 
                                                                   ; 'infantmort' is a user adjustable slider. This works the same way as 'disease' and 'epidemics'.
                                                                   ; This code allows the user to change the infant susceptibility of disease in relation to adults.
                                        [ set death-child death-child + 1 
                                          brown-bread ]]

end



; this subroutine works in an identical fashion as the child-age-die routine above.

to age-die
  
  if needs < 0
    [ set death-starvation death-starvation + 1
      set wealthdeathno wealthdeathno + 1
      if class-ranking = 1 [ set rankdeath1 rankdeath1 + 1 ]
      if class-ranking = 2 [ set rankdeath2 rankdeath2 + 1 ]
      if class-ranking = 0 [ set rankdeath0 rankdeath0 + 1 ]
      brown-bread ]
    set age age + 1                     
  if random-float epidemics - random-float ((needs * natural-medical) + sqrt ((propensity-health * wants * tech-medical))) >= plague 
     [ set death-epidemic death-epidemic + 1
       brown-bread ]  
  if accidents > 0 and random (300 - accidents) = 0
     [ set death-accident death-accident + 1
       brown-bread ]
  if disease > 0 [ ifelse age <= old-age
                        [  if random (300 - Disease + (needs * natural-medical) + sqrt ((propensity-health * wants * tech-medical))) - random (land-usage * toxicity) <= 0 
                          [ set death-disease death-disease + 1
                            brown-bread ]]
                          
                        [  if random (300 - Disease + (needs * natural-medical) + sqrt ((propensity-health * wants * tech-medical))) - random (age + (land-usage * toxicity)) <= 0 
                          [ set death-age death-age + 1
                            brown-bread ]]]
                          
 if child-dependency = 0 and age < 5 and infantmort > 0             ; this allows the user to impose a child mortality without requiring a child-dependency. Defining the age of a child as 5 is simply a programmer choice.
          [ if random (25 - infantmort + (needs * natural-medical) + sqrt (propensity-health * wants * tech-medical)) - random (land-usage * toxicity) <= 0 
            [ set death-child death-child + 1 
              brown-bread ]]
 
 ; This code determines reproduction. 'birth_control', 'Fecundity_Policy' and 'child_limit' are user adjustable sliders for experimenting with reproductive policy impacts.
 ; child-self-limit and child-need-buffer are user adjustable sliders that simulate the decision to have less children and a minimum 'need' requirement respectively.
 ; the 'Child-Need-Buffer' becomes an agent evolutionary variable if set to 0. Currently, the best way to set the slider for minimum impact is to set it just above 0.
 
 ifelse birth_control + Fecundity_Policy + child_limit = 0
       [ if  age > 11 and random (age) + (child-self-limit * children) < fertile and needs > (living-cost * Child-Need-Buffer)
          [ birth ]]
       [ if age > 11 and random (age)  + (child-self-limit * children) < (fertile - birth_control) and (fecundity < Fecundity_Policy or Fecundity_Policy = 0) and (children < child_limit or child_limit = 0) and needs > (living-cost * Child-Need-Buffer)
          [ birth ]]
       
 ; 'birth-control' directly impacts the probability of reproducing at all stages. 'child_limit' simulates the Chinese laws of a maximum number of children.
 ; 'Fecundity_Policy' explores the imaginary possibility that policy-makers could set a maximum system-wide fecundity purely for the sake of interest.


 if disease = 0 and age > old-age [ if random 10 = 0 [ set death-age death-age + 1
                                                       brown-bread ]]
 ; 'old-age' is a user adjustable slider that approximately enforces a maximum age on the agents.
 
end


; This tranfers apparently successful bahviour to a less successful agent

to Cultural-Transfer

  ask one-of people-here with-max [ total-wealth ] [
  let trade-no order-of-trade
  let eco-knowledge industrial-innovate
  let nn nurture-needs
  let nw nurture-wants
  let nm nurture-money
  let sw savings-wants
  let pup price-up
  let pdown price-down
  let plabour  propensity-labour 
  let phealth  propensity-health  
  ask self [ set order-of-trade trade-no
             set industrial-innovate eco-knowledge
             if random 20000 - 1 < mutation [ set nurture-needs nn
                                              set nurture-wants nw
                                              set nurture-money nm ]
             if random 5000 - 1 < mutation [ set price-up pup
                                             set price-down pdown
                                             set savings-wants sw ]
             if random 20000 - 1 < mutation [ set propensity-labour plabour
                                              set propensity-health phealth ]]]


end


; This routine creates new agents.
 
to birth
 
       hatch 1 [
         set birth-rate birth-rate + 1                                                ; This is for graphing purposes.
         set children 0                                                               ; This is for graphing and birth control purposes.
         set needs needs * nurture-needs                                              ; 'nurture-needs' is an evolutionary variable. This is the percentage of 'needs' a parent gives its child at birth
         set wants wants * nurture-wants                                              ; 'nurture-wants' is an evolutionary variable. This is the percentage of 'wants' a parent gives its child at birth
         ifelse child-dependency > 0 [ set money-available money * nurture-money      ; 'nurture-money' is an evolutionary variable. This is the percentage of 'money' a parent gives its child at birth
                                       set money 0 ]                                  ; 'money-available' stores money to it cannot be immediately spent if the user slider 'child-dependency' is above 0.
                                     [ set money money * nurture-money]
         set genetic-marker-kids genetic-marker-parent                                ; This links the child to parent for inheritance purposes.
         set genetic-marker-parent random-float 1000
         set age 0
         set labour 0
         
        
        ; The following code is how all the evolutionary variables are mutated. The ranges are mainly the result of experimentation.
        ; For example, originally 'mutation' was a user adjustable slider. It was determined that above a certain range the agents would die off. Thus the top range of 'mutation' goes just into that extinction range.
        ; The simplest code was a single test of 'mutution' and if 'true' then everything mutated. In this simulation, it seemed to work just as well the code presented here. 
        ; Intellectually it seemed that this code might capture things that the simpler code could not and since it did not significantly slow down the simulator, it was left this way.
        ; See 'Agent Evolutionary Variables' under the 'Information' tab for variable description.

         if random 10000 - 1 < mutation [      
               set mutation mutation + random 10 - random 10
                if mutation < 0 [set mutation 0]]
         if random 10000 - 1 < mutation [
               set nurture-needs nurture-needs + (random-float 1 / 10) - (random-float 1 / 10)
                if nurture-needs < 0 [set nurture-needs 0]
                if nurture-needs > 1 [set nurture-needs 1]]
         if random 10000 - 1 < mutation [
               set vision vision + random-float 1 - random-float 1
                if vision < 0 [ set vision 0 ]] 
         if random 1000 - 1 < mutation [
               set fertile fertile + random-float 2 - random-float 2
                if fertile < 0 [set fertile 0]] 
         if random 10000 - 1 < mutation [
               set charity charity + random-float .1 - random-float .1
                if charity > 1 [set charity 1]
                if charity < 0 [set charity 0]]
         if random 10000 - 1 < mutation [
               set movement movement - random 2 + random 2]
               if movement < 0 [ set movement 0 ]
         if random 10000 - 1 < mutation [
               set movement-wants movement-wants - random 2 + random 2]
               if movement-wants < 0 [ set movement-wants 0 ]
         if random 10000 - 1 < mutation [
               set exploration exploration - random 10 + random 10 ]
               if exploration < 0 [ set exploration 0 ]
         if random 10000 - 1 < mutation [
               set savings-rate-needs savings-rate-needs + random-float .5 - random-float .5
                if savings-rate-needs <= 0 [set savings-rate-needs 0]]
         if random 10000 - 1 < mutation and NBB_Evolve = true [
               set child-need-buffer child-need-buffer + random-float 2 - random-float 2
               if child-need-buffer < 0 [ set child-need-buffer 0 ]]
         if random 10000 - 1 < mutation [
               set money-value money-value + random-float .2 - random-float .2
               if money-value < 0 [ set money-value 0 ]]


if industrial-innovate > 0 [
         if random 10000 - 1 < mutation [
               set nurture-money nurture-money + (random-float 1 / 10) - (random-float 1 / 10)
                if nurture-money < 0 [set nurture-money 0]
                if nurture-money > 1 [set nurture-money 1]]
         if random 10000 - 1 < mutation [
               set price-up price-up + random-float .001 - random-float .001
                if price-up <= 0 [set price-up .00001]]
         if random 10000 - 1 < mutation [
               set price-down price-down + random-float .001 - random-float .001
                if price-down <= 0 [set price-down .00001]
                if price-down > .999999 [set price-down .99999 ]]
         ]

If industrial-innovate > 1 [
  
         if random 10000 - 1 < mutation [
               set nurture-wants nurture-wants + (random-float 1 / 10) - (random-float 1 / 10)
                if nurture-wants < 0 [set nurture-wants 0]
                if nurture-wants > 1 [set nurture-wants 1]]
         if random 10000 - 1 < mutation [
               set savings-wants savings-wants + random .5 - random .5
                if savings-wants < 0 [set savings-wants 0]]     
         if random 10000 - 1 < mutation [
               set migration migration + random-float .1 - random .1
                if migration < 0 [set migration 0]
                if migration > 1 [set migration 1]]

         if random 10000 - 1 < mutation [
               set needs-stock needs-stock + random living-cost - random living-cost
                if needs-stock < 0 [set needs-stock 0]]              if random 10000 - 1 < mutation [
               let propensity-capital 1 - propensity-labour - propensity-health
               set propensity-labour propensity-labour + random-float .3 - random-float .3
                 if propensity-labour < 0 [ set propensity-labour 0 ]
               set propensity-health propensity-health + random-float .3 - random-float .3
                 if propensity-health < 0 [ set propensity-health 0 ]
               set propensity-capital propensity-capital + random-float .3 - random-float .3
                 if propensity-capital < 0 [ set propensity-capital 0 ]
               let all propensity-labour + propensity-health + propensity-capital
               set propensity-labour propensity-labour / all
               set propensity-health propensity-health / all
              
               set propensity-use-needs propensity-use-needs + random-float .10 - random-float .10
                 if propensity-use-needs < 0 [ set propensity-use-needs 0 ]
                 if propensity-use-needs > 1 [set propensity-use-needs 1]]
                            ]

If industrial-innovate > 2 [
          if random 10000 - 1 < mutation 
               [set order-of-trade random 12 ]]
        ]

          set needs needs - (needs * nurture-needs)
          set money money - (money * nurture-money)        
          set wants wants - (wants * nurture-wants)     
          set children children + 1
          
end
                                      

; It is envisioned that this code could simulate charity or sharing.

to do-charity
   let my-charity 0
   prepare-trade                                        ; this ensures an agent is only offering what is surplus.
   if needs-offered > 0
     [ if any? other people-here with [beg = 1]               ; If there are any agents needing charity ...
         [set my-charity needs-offered * charity        ; let's give them some of my surplus according to my evolved 'charity' variable.
          set needs needs - my-charity
          set act-of-charity act-of-charity + 1         ; This is for graphing purposes.
          ask one-of other people-here with [ beg = 1 ]       ; find someone who needs help
              [ set needs needs + my-charity
                if needs > living-cost * giving-threshold [ set beg 0 ]]]    ; Thanks for the charity. If I have enough, I will stop asking.
                                                                             ; 'giving-threshold' is a user adjustable slider.
                                                        
          ]
   
end

; This is the death and inheritance code.

to brown-bread
  
;  if count people < 3 [ die                                      ; this conditional statement prevents the simulator from crashing by searching an finding no one.
 ;                       set totalpop count people
  ;                      ask observer [ go ]
;  if industrial-innovate < 2 [ set industrial-innovate max [ industrial-innovate ] of people]
  if industrial-innovate < 2 [ set wants 0 ]
  let commercial-knowledge industrial-innovate 
  let inherited-wants wants * ( .85 + random-float .15)          ; This simulates people throwing away old stuff.
  let inherited-money money + money-available
  let genetic-marker-search genetic-marker-parent
  
  ifelse any? people with [genetic-marker-kids = genetic-marker-search]  ; Do any children survive? If yes, then here is the Will ...
      [ ask one-of people with [genetic-marker-kids = genetic-marker-search] ; Favouritism is assumed in this simulation. Only one child gets the goodies.
        [ set wants wants + inherited-wants
          set money money + inherited-money 
          if industrial-innovate < commercial-knowledge [ set industrial-innovate commercial-knowledge]]]
      [ Ask min-one-of other people [distance myself]  [ set money money + inherited-money
                                                         set wants wants + inherited-wants 
                                                         if industrial-innovate < commercial-knowledge [set industrial-innovate commercial-knowledge]]]                                                    ; if no children survive, let's just give it to the nearest agent.
        
  
  set death-rate death-rate - 1                                                          ; This is for graphing purposes.
  set death-rate-adults death-rate-adults + 1                                            ; This is for graphing purposes.
  set ave-death-age ave-death-age + age
 
  die                                                                                    ; finally, the last breath is drawn.

end



to explore                                    ; This allows any agent to travel and explore. 'Exploration' is an evolutionary variable.
           
   if random exploration = 0       
         [ set wander 2
           move ]
                                                      
end

; This is the subroutine that controls the movement of the agents.

to move
    let randomheading random 360  
    if wander = 1                                                       ; 'wander' is set to 1 when an agent isn't finding the 'needs' it is seeking.
      [ repeat 3 [  
        ifelse vision >= 1 [face max-one-of patches in-radius vision [resource-value]]     ; 'resource-value' is a patch calculated variable to vaguely indicate better prospects
                           [set heading randomheading]                                     ; if we can't see, then any direction is as good as any other.
             
        if wants > 0 [set wants wants - (travel-cost * wants * (1 / (10 + land-usage)))]   ; This tallies up the cost. 'travel-cost' is a user adjustable slider. On the other hand, industrialisation tends to make travel easier.
        fd .334 ]]
        
                                              
    if wander = 2                                                       ; 'wander' is set to 2 when and agent chooses to explore.
      [ set heading random 360
        let cost-limit 0
        let move-tech sqrt (wants * propensity-labour)                  ; using 'wants' to empower an agent also allows them to travel further.
        if move-tech > Max-Move and max-move > 0 [ set cost-limit move-tech / Max-Move   ; 'max-move' is a user adjustable slider. 'Cost-limit' keeps the cost in 'wants' in line with 'max-move'
                                                   set move-tech Max-Move ]              ; 'tech-move' is how much 'wants' is going to empower the move.
        repeat (random-float 3  + (migration * move-tech))              ; 'migration' is an agent evolutionary variable that allows agents to adjust it's average distance of travel.
           [ fd .9
             set heading heading + random 25 - random 25 ]              ; exploration rarely takes us to a planned place.
         set wants wants - (travel-cost * wants * propensity-labour * migration * (1 / (1 + land-usage)) * cost-limit)  ; This tallies up the cost.
         if wants < 0 [ set wants 0 ]]
     
    if wander = 3                                                       ; 'wander' is set to 1 when an agent isn't finding the 'wants' it is seeking. This follows the same process as 'wander = 1' except it relates to 'wants'.
      [ repeat 3 [
        ifelse vision >= 1 [ face max-one-of patches in-radius vision [extraction-value ]]  ; 'extraction-value' is a patch calculated variable to vaguely indicate better prospects
                           [ set heading randomheading ]
        if wants > 0 [ set wants wants - ( travel-cost * wants * ( 1 / ( 10 + land-usage ))) ]
        fd .334 ]]
     
    set wander 0                                                      
                                                                  
end                                                               



; The rest of the coding only relates to the graphs. 
; This simulator generates an enormous amount of information and there are many more possible graphs. 
; For example, in the past, wealth has been graphed purely in terms of money so that the system prices were reflected in the wealth of an agent. 
; As it is, wealth is calculated purely in the stock of 'needs' 'wants' and 'money'. Both ways have merit in regards to understanding what is happening in the system.
; However, there are limits to what can be done with the computers currently available to this experimenter.

to update-plot-variables
 
set totalpop count people                         ; this number is used a lot in graphing
set totalpop1 totalpop1 + totalpop                ; this adds the population for gaps in graphing as set by the user.
if totalpop > peak-population [ set peak-population totalpop ]
if totalpop = 0 [ stop ]
; This code assigns a 'class-ranking' to agents according to their wealth

let counter 0
  ask people with [ age >= child-dependency ]
    [ if child-dependency > 0 [ set total-wealth total-wealth + sum [ total-wealth ] of people with [ genetic-marker-kids = [ genetic-marker-parent ] of self and age < child-dependency ]
                                ask people with [ genetic-marker-kids = [ genetic-marker-parent ] of self and age < child-dependency ] [ set total-wealth 0 ]]
      set class-ranking 1]
      foreach sort-by [[total-wealth] of ?1 < [total-wealth] of ?2] people
        [ ask ? [ set counter counter + 1
                  if counter / totalpop <= bottom-wealth-cutoff-% [set class-ranking 0]
                  if counter / totalpop >= middle-wealth-cutoff-% [set class-ranking 2]]]

set poplow count people with [ class-ranking = 0 ]
set popmid count people with [ class-ranking = 1 ]
set poptop count people with [ class-ranking = 2 ]

; 'colour' is a user switch.

if colour = true [set wealth-colour false]           
If wealth-colour [ask people [ if class-ranking = 0 [set color red]
                               if class-ranking = 1 [set color yellow]
                               if class-ranking = 2 [set color blue]]
                              ]

; 'poplow', 'popmid', and 'pophigh' are the total calculated wealth in each class.

ifelse poplow > 0
 [ set bottom-third sum [ total-wealth ] of people with [ class-ranking = 0 ] / poplow
   set bottom-third1 bottom-third1 + bottom-third]
 [ set bottom-third 0 ]

ifelse popmid > 0
 [ set middle-third sum [ total-wealth ] of people with [ class-ranking = 1 ] / popmid
   set middle-third1 middle-third1 + middle-third ]
 [ set middle-third 0 ]

ifelse poptop > 0
 [ set top-third sum [ total-wealth ] of people with [ class-ranking = 2 ] / poptop
   set top-third1 top-third1 + top-third ]
 [ set top-third 0 ]
   
  
  set goods-production1 goods-production1 + goods-production             ; calculates the total harvest of 'wants'
  
  set per-Capita-Productivity1 per-Capita-Productivity1 + ((food-production + (goods-production1 / 300)) / ( count people with [age > child-dependency] + .0000000000001 )) 
                                       ; Calculates system productivity. Using the root of 'wants' production makes the graphs legible. 
                                       ; Othewise, the production of 'wants' dwarfs the production of 'needs'. The fractional addition prevents division by 0.
  
  set all-wealth1 all-wealth1 + sum [ total-wealth ] of people
      
  if trade-needs > 0 [
  set needs-pricing1 needs-pricing1 + (economy-needs / volume-needs)]  ; calculates the average price of 'needs'
  
  if trade-wants > 0 [
  set wants-pricing1 wants-pricing1 + (economy-wants / volume-wants)]  ; calculates the average price of 'wants'
  
  set trade-needs1 trade-needs1 + trade-needs                          ; calculates the number of trades of 'needs'.
  set trade_innovate0 trade_innovate0 + count people ; with [ industrial-innovate > 0 ]
  
  set trade-wants1 trade-wants1 + trade-wants                          ; calculates the number of trades of 'wants'.
  set trade_innovate1 trade_innovate1 + count people ; with [ industrial-innovate > 1 ]
    
  set death-starvation1 death-starvation1 + (death-starvation / totalpop)
  set death-age1 death-age1 + (death-age / totalpop)
  set death-epidemic1 death-epidemic1 + (death-epidemic / totalpop)
  set death-accident1 death-accident1 + (death-accident / totalpop)
  set death-disease1 death-disease1 + (death-disease / totalpop)
  set death-child1 death-child1 + (death-child / totalpop)
  Let adults count people with [age > child-dependency]
  
  set beggers1 beggers1 + (beggers / totalpop)                          ; calculates the number of beggers as a percent of the population
  set act-of-charity1 act-of-charity1 + (act-of-charity / totalpop)     ; calculates the number of charity acts as a percent of the population
  
  if count people with [age > child-dependency] > 0 [ set surplus1 surplus1 + (sum [ needs ] of people / count people with [age > child-dependency] / living-cost) ] ; Calculates the amount of 'needs' over the 'living-cost'. Any labour not required to feed an agent is considered surplus labour. 
  
  if count people with [ age > 11 ] > 0 [ set fecundity1 fecundity1 + sum [ children ] of people / count people with [ age > 11 ]] ; Calculates the fecundity in the system based on all agents capable of reproduction.
  
  set ave-death-age1 ave-death-age1 + ave-death-age
  set death-rate-adults1 death-rate-adults1 + death-rate-adults
  
  set death-rate1 death-rate1 + (death-rate / totalpop)                 ; This calculates the negative rate of death as a percentage of the population (deaths are subtracted instead of added)
  set birth-rate1 birth-rate1 + (birth-rate / totalpop)                 ; This calculates the rate of birth as a percentage of the population.
  
  set children-poor-people children-poor-people + sum [children] of people with [ class-ranking = 0 ] / (count people with [ class-ranking = 0 and age > 11 ] + .00000000000001)
  set children-rich-people children-rich-people + sum [children] of people with [ class-ranking = 2 ] / (count people with [ class-ranking = 2 and age > 11 ] + .00000000000001)
  set fertility-poor-people fertility-poor-people + sum [ 100 - fertile ] of people with [ class-ranking = 0 ] / (count people with [ class-ranking = 0 ] + .00000000000001)
  set fertility-rich-people fertility-rich-people + sum [ 100 - fertile ] of people with [ class-ranking = 2 ] / (count people with [ class-ranking = 2 ] + .00000000000001)
 

; This sets the single iteration variables to 0.
 
  set death-starvation 0
  set death-age 0 
  set death-epidemic 0
  set death-accident 0
  set death-disease 0
  set death-child 0
  

; 'start-graphs' is a user adjustable slider. This sets up the graphs to start properly in the event of a delayed start. Starts can be delayed because the graphs can be chaotic at the beginning of a simulation run, making it difficult to read when the extremes are worked out.
  if ticks + graphing-interval = start-graphs [ zero-graph-variables ]
  
  if graphing >= graphing-interval and ticks >= start-graphs [ ifelse graphing-interval-last = graphing-interval    ; 'graphing-interval' and 'start-graphs' are user adjustable sliders. This controls the graphing interval.
                                                                  [ update-plot ]
                                                                  [ set graphing-interval-last graphing-interval    ; this allows the user to change the interval while the simulation is running
                                                                    zero-graph-variables ]]                                 
  
  set graphing graphing + 1   ; this keeps track of graphing intervals.
  
  
end

; See 'Graphs and Moniters' under the 'Information' tab for more information about the graphs.

   
to update-plot    
  
  let sorted-wealths sort [total-wealth] of people                                ; This generates the Gini coefficient.
  let sum-wealth sum sorted-wealths
  let wealth-sum-so-far 0
  let index 0
  let gini-index-reserve 0
  repeat totalpop [
    set wealth-sum-so-far (wealth-sum-so-far + item index sorted-wealths)
    set index (index + 1)
    set gini-index-reserve gini-index-reserve + (index / totalpop) - (wealth-sum-so-far / sum-wealth) 
    ]
 
  if gini-base-line = 0 [ set gini-base-line (gini-index-reserve / totalpop) / 0.5 ]
 
  set-current-plot "Gini Coefficient"
  Set-current-plot-pen "gini"
  plot (gini-index-reserve / totalpop) / 0.5
  Set-current-plot-pen "base"
  plot gini-base-line
  
  set-current-plot "per Capita Productivity"
  Set-current-plot-pen "productivity"
  plot per-Capita-Productivity1 / graphing-interval
  Set-current-plot-pen "survival"
  plot living-cost
  
 ; if ticks > ( start-industrialisation + 200 ) [ if per-Capita-Productivity1 > max-cap [ set max-cap per-Capita-Productivity1 ]
 ;                                                if totalpop > 500 and per-Capita-Productivity1 < (.7  * max-cap) [ set max-cap1 1 ]]
  
  set-current-plot "Stay at Home"
  Set-current-plot-pen "Max"
  plot min [ exploration ] of people
  Set-current-plot-pen "Ave"
  plot sum [ exploration] of people / totalpop
  Set-current-plot-pen "Min"
  plot max [ exploration ] of people
                                      
  set-current-plot "Non-Renewable Reserves"
  Set-current-plot-pen "fixed"
  plot sum [ fixed-resources-here ] of patches
       
  set-current-plot "Food Per Capita"
  set-current-plot-pen "zero"
  plot surplus1 / graphing-interval
  
  set-current-plot "Population"
  set-current-plot-pen "Top"
  plot totalpop1 / graphing-interval
  
  set-current-plot "Prices"
  set-current-plot-pen "Needs"
  plot needs-pricing1 / graphing-interval
  set-current-plot-pen "Tech"
  plot wants-pricing1 / graphing-interval
  
  set-current-plot "# of Trades / capita"
  set-current-plot-pen "Needs"
  ifelse trade_innovate0 > 0
    [ plot trade-needs1 / trade_innovate0 ]
    [ plot 0 ]
  set-current-plot-pen "Tech"
  ifelse trade_innovate1 > 0  
    [ plot trade-wants1 / trade_innovate1 ]
    [ plot 0 ]
  
  set-current-plot "Total Wealth/Capita"
  set-current-plot-pen "w/c"
  plot all-wealth1 / totalpop / graphing-interval
  
  set-current-plot "Fertility"
  Set-current-plot-pen "P"
  plot fertility-poor-people / graphing-interval
  Set-current-plot-pen "R"
  plot fertility-rich-people / graphing-interval
  
  set-current-plot "Fecundity"
  set-current-plot-pen "Children"
  plot fecundity1 / graphing-interval
  
  set-current-plot "Children by Wealth"
  Set-current-plot-pen "P"
  plot children-poor-people / graphing-interval
  set-current-plot-pen "R"
  plot children-rich-people / graphing-interval
  
  set-current-plot "Needs Stock"
  Set-current-plot-pen "Max"
  plot max [ needs-stock ] of people
  Set-current-plot-pen "Ave"
  plot sum [ needs-stock ] of people / totalpop
  Set-current-plot-pen "Min"
  plot min [ needs-stock ] of people
  
  set-current-plot "nurturing needs"
  Set-current-plot-pen "Max"
  plot max [nurture-needs] of people
  Set-current-plot-pen "Ave"
  plot sum [nurture-needs] of people / totalpop
  Set-current-plot-pen "Min"
  plot min [nurture-needs] of people
  
  set-current-plot "nurturing money"
  Set-current-plot-pen "Max"
  plot max [nurture-money] of people
  Set-current-plot-pen "Ave"
  plot sum [nurture-money] of people / totalpop
  Set-current-plot-pen "Min"
  plot min [nurture-money] of people
  
  set-current-plot "nurturing tech"
  Set-current-plot-pen "Max"
  plot max [nurture-wants] of people
  Set-current-plot-pen "Ave"
  plot sum [nurture-wants] of people / totalpop
  Set-current-plot-pen "Min"
  plot min [nurture-wants] of people
  
  set-current-plot "Mutation"
  Set-current-plot-pen "Max"
  plot max [mutation] of people
  Set-current-plot-pen "Ave"
  plot sum [mutation] of people / totalpop
  Set-current-plot-pen "Min"
  plot min [mutation] of people
  
  set-current-plot "Need-Birth-Buffer"
  Set-current-plot-pen "Max"
  plot max [Child-Need-Buffer] of people
  Set-current-plot-pen "Ave"
  plot sum [Child-Need-Buffer] of people / totalpop
  Set-current-plot-pen "Min"
  plot min [Child-Need-Buffer] of people
  
  set-current-plot "Economic Cultures"
  Set-current-plot-pen "HG"
  plot count people with [ industrial-innovate = 0 ] / totalpop
  Set-current-plot-pen "Tr"
  plot count people with [ industrial-innovate = 1 ] / totalpop
  Set-current-plot-pen "In"
  plot count people with [ industrial-innovate = 2 ] / totalpop
  Set-current-plot-pen "Ind"
  plot count people with [ industrial-innovate = 3 ] / totalpop 
  
  if charity-strength > 0 [
  set-current-plot "Charity"
  Set-current-plot-pen "Max"
  plot max [Charity] of people
  Set-current-plot-pen "Ave"
  plot sum [Charity] of people / totalpop
  Set-current-plot-pen "Min"
  plot min [Charity] of people
  
  Set-current-plot "Charity Activity"
  set-current-plot-pen "Beg"
  plot beggers1 / graphing-interval
  set-current-plot-pen "Give"
  plot act-of-charity1 / graphing-interval ]
      
  set-current-plot "Health Choice"
  Set-current-plot-pen "Max"
  plot max [propensity-health] of people
  Set-current-plot-pen "Ave"
  plot sum [propensity-health] of people / totalpop
  Set-current-plot-pen "Min"
  plot min [propensity-health] of people
  
  set-current-plot "Vision"
  Set-current-plot-pen "Max"
  plot max [vision] of people
  Set-current-plot-pen "Ave"
  plot sum [vision] of people / totalpop
  Set-current-plot-pen "Min"
  plot min [vision] of people
  set-current-plot-pen "1"
  plot 1
  
  set-current-plot "Saving Rates"
  Set-current-plot-pen "Needs"
  plot (sum [savings-rate-needs] of people) / totalpop
  Set-current-plot-pen "Tech"
  plot sum [savings-wants] of people / totalpop

  set-current-plot "Birth and Death"
  Set-current-plot-pen "Death"
  plot death-rate1 / graphing-interval
  Set-current-plot-pen "Birth"
  plot birth-rate1 / graphing-interval
  Set-current-plot-pen "Mean"
  plot 0
  Set-current-plot-pen "top"
  plot .05
  Set-current-plot-pen "bottom"
  plot -.05
  
  set-current-plot "Technological Travel"
  Set-current-plot-pen "Max"
  plot max [migration] of people
  Set-current-plot-pen "Ave"
  plot sum [migration] of people / totalpop
  Set-current-plot-pen "Min"
  plot min [migration] of people
  
  set-current-plot "Cause of Death"
  Set-current-plot-pen "starve"
  plot death-starvation1 / graphing-interval
  Set-current-plot-pen "age"
  plot death-age1 / graphing-interval
  Set-current-plot-pen "plague"
  plot death-epidemic1 / graphing-interval
  Set-current-plot-pen "accident"
  plot death-accident1 / graphing-interval
  Set-current-plot-pen "Disease"
  plot death-disease1 / graphing-interval
  Set-current-plot-pen "infant"
  plot death-child1 / graphing-interval
  
  
  set-current-plot "Trading Culture 1"
  Set-current-plot-pen "1"
  plot count people with [order-of-trade = 0] / totalpop
  Set-current-plot-pen "2"
  plot count people with [order-of-trade = 1] / totalpop
  Set-current-plot-pen "3"
  plot count people with [order-of-trade = 2] / totalpop
  Set-current-plot-pen "4"
  plot count people with [order-of-trade = 3] / totalpop
  Set-current-plot-pen "5"
  plot count people with [order-of-trade = 4] / totalpop
  Set-current-plot-pen "6"
  plot count people with [order-of-trade = 5] / totalpop
  
  set-current-plot "Trading Culture 2"
  Set-current-plot-pen "1"
  plot count people with [order-of-trade = 6] / totalpop
  Set-current-plot-pen "2"
  plot count people with [order-of-trade = 7] / totalpop
  Set-current-plot-pen "3"
  plot count people with [order-of-trade = 8] / totalpop
  Set-current-plot-pen "4"
  plot count people with [order-of-trade = 9] / totalpop
  Set-current-plot-pen "5"
  plot count people with [order-of-trade = 10] / totalpop
  Set-current-plot-pen "6"
  plot count people with [order-of-trade = 11] / totalpop
  
  set-current-plot "life span"
  ifelse death-rate-adults1 > 0
  [ plot ave-death-age1 / death-rate-adults1 ]
  [ plot 0 ]
  
set-current-plot "child ratio"
  
  let y count people with [age < 12]
  plot y / count people
  
set-current-plot "class death"
if wealthdeathno > 0 [ 
  Set-current-plot-pen "death-child-dep" 
  plot death-child-dep / wealthdeathno
  Set-current-plot-pen "rankdeath0"
  plot rankdeath0 / wealthdeathno 
   Set-current-plot-pen "rankdeath1"
  plot rankdeath1 / wealthdeathno
   Set-current-plot-pen "rankdeath2"
  plot rankdeath2 / wealthdeathno ]

zero-graph-variables

end

; This subroutine zeros the graphical variables once plotting has occurred.

to zero-graph-variables
  
  set death-starvation1 0
  set death-age1 0 
  set death-epidemic1 0
  set death-accident1 0
  set death-disease1 0 
  set death-child1 0
  set death-starvation1 0
  set death-age1 0 
  set death-epidemic1 0
  set death-accident1 0
  set death-disease1 0
  set death-child1 0
  set ave-death-age 0
  set death-rate-adults 0
  set Graphing 0 
  set bottom-third1 0
  set middle-third1 0
  set top-third1 0
  set goods-production1 0 
  set per-Capita-Productivity1 0
  set all-wealth1 0
  set needs-pricing1 0
  set wants-pricing1 0
  set trade-needs1 0
  set trade-wants1 0
  set surplus1 0
  set totalpop1 0
  set trade_innovate0 0 
  set trade_innovate1 0
  set fecundity1 0
  set ave-death-age1 0
  set death-rate-adults1 0
  set beggers1 0
  set act-of-charity1 0
  set death-rate1 0
  set birth-rate1 0
  set children-poor-people 0
  set children-rich-people 0
  set fertility-poor-people 0
  set fertility-rich-people 0
  set wealthdeath 0
  set wealthdeathno 0
  set rankdeath1 0
  set rankdeath2 0
  set rankdeath0 0
  set death-child-dep 0
  
end
@#$#@#$#@
GRAPHICS-WINDOW
144
82
578
457
26
21
8.0
1
10
1
1
1
0
1
1
1
-26
26
-21
21
1
1
1
Time
30.0

BUTTON
3
83
62
116
setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
86
83
141
116
go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
4
10
147
43
num-people
num-people
50
2000
1100
50
1
NIL
HORIZONTAL

SLIDER
172
10
358
43
Max-Renewable-Resources
Max-Renewable-Resources
10
100
26
1
1
NIL
HORIZONTAL

SLIDER
4
49
145
82
Starting-Labour
Starting-Labour
1
10
4.2
.1
1
NIL
HORIZONTAL

SLIDER
1
118
142
151
Living-Cost
Living-Cost
0
5
2.4
.1
1
NIL
HORIZONTAL

MONITOR
834
88
893
133
Population
totalpop
0
1
11

SLIDER
3
221
142
254
Epidemics
Epidemics
0
100
0
1
1
NIL
HORIZONTAL

PLOT
582
300
827
450
per Capita Productivity
Time
Productivity
0.0
200.0
2.0
2.01
true
false
"" ""
PENS
"Productivity" 1.0 0 -8630108 true "" ""
"survival" 1.0 0 -16777216 true "" ""

SLIDER
365
10
551
43
Renewable-Harshness
Renewable-Harshness
5
500
40
1
1
NIL
HORIZONTAL

SLIDER
2
186
142
219
InfantMort
InfantMort
0
25
0
.1
1
NIL
HORIZONTAL

PLOT
833
458
1089
607
Birth and Death
Time
Death  l  Birth
0.0
200.0
-0.07
0.07
true
false
"" ""
PENS
"Death" 1.0 0 -16777216 true "" ""
"Birth" 1.0 0 -16777216 true "" ""
"Mean" 1.0 0 -6459832 true "" ""
"top" 1.0 0 -955883 true "" ""
"bottom" 1.0 0 -955883 true "" ""

SLIDER
172
48
356
81
Max-Fixed-Resources
Max-Fixed-Resources
1
10
4
.1
1
NIL
HORIZONTAL

SLIDER
366
48
550
81
Fixed-Harshness
Fixed-Harshness
2
500
70
1
1
NIL
HORIZONTAL

PLOT
204
906
403
1056
Stay at Home
Time
Propensity
0.0
200.0
0.0
10.0
true
false
"" ""
PENS
"Ave" 1.0 0 -16777216 true "" ""
"Max" 1.0 0 -2674135 true "" ""
"Min" 1.0 0 -10899396 true "" ""

SLIDER
966
311
1099
344
Initial-Wave2
Initial-Wave2
0
100
0
5
1
NIL
HORIZONTAL

PLOT
579
611
827
763
Food Per Capita
Time
Surplus Needs
0.0
200.0
0.0
1.0
true
false
"" ""
PENS
"Total" 1.0 0 -16777216 false "" ""
"zero" 1.0 0 -10899396 true "" ""

PLOT
581
138
826
291
Population
Time
People
0.0
200.0
0.0
10.0
true
false
"" ""
PENS
"Top" 1.0 0 -16777216 false "" ""

SLIDER
690
837
861
870
Bottom-Wealth-Cutoff-%
Bottom-Wealth-Cutoff-%
.01
middle-wealth-cutoff-%
0.4
.01
1
NIL
HORIZONTAL

SLIDER
689
799
862
832
Middle-Wealth-Cutoff-%
Middle-Wealth-Cutoff-%
Bottom-wealth-cutoff-%
.99
0.89
.01
1
NIL
HORIZONTAL

SLIDER
1020
837
1167
870
Recycling
Recycling
0
5
3
.1
1
NIL
HORIZONTAL

BUTTON
1054
1064
1186
1097
Environmental Disruption
set max-renewable-resources max-renewable-resources-memory  * (1 - Environmental-Degradation)\nset renewable-harshness Harshness-memory * (1 +  Environmental-Degradation)\nsetup-patch-renewables\nask patches [set resource-value (renewable-resource-here - (living-cost * (count people-here + 1))) * (sum [labour ] of people-here / harvest-cost)]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
981
187
1059
232
Wealth Low
bottom-third
0
1
11

MONITOR
981
141
1058
186
Wealth Mid
middle-third
0
1
11

MONITOR
981
95
1058
140
Wealth Top
top-third
0
1
11

PLOT
810
1377
1010
1527
Prices
Time
Amount Paid
0.0
200.0
0.0
5.0
true
false
"" ""
PENS
"Needs" 1.0 0 -10899396 true "" ""
"Tech" 1.0 0 -8630108 true "" ""

PLOT
317
459
565
609
# of Trades / capita
Time
Trades
0.0
200.0
0.0
1.0
true
false
"" ""
PENS
"Needs" 1.0 0 -10899396 true "" ""
"Tech" 1.0 0 -8630108 true "" ""

PLOT
579
458
826
608
Total Wealth/Capita
Time
Wealth/Capita
0.0
200.0
0.0
10.0
true
false
"" ""
PENS
"w/c" 1.0 0 -16777216 true "" ""

SLIDER
3
255
142
288
Disease
Disease
0
299
0
1
1
NIL
HORIZONTAL

SLIDER
559
10
727
43
Renewable-Soft-Patch
Renewable-Soft-Patch
0
1500
1030
10
1
NIL
HORIZONTAL

SLIDER
558
48
727
81
Fixed-Soft-Patch
Fixed-Soft-Patch
0
1500
950
10
1
NIL
HORIZONTAL

SLIDER
1037
1102
1217
1135
Environmental-Degradation
Environmental-Degradation
0
.99
0
.05
1
NIL
HORIZONTAL

PLOT
607
1064
814
1214
Fertility
Time
Class Fertility
0.0
200.0
90.0
90.0
true
true
"" ""
PENS
"R" 1.0 0 -14835848 true "" ""
"P" 1.0 0 -2674135 true "" ""

PLOT
816
1064
1008
1214
Fecundity
Time
Children/Adult
0.0
200.0
0.0
0.1
true
false
"" ""
PENS
"Children" 1.0 0 -16777216 true "" ""

MONITOR
721
87
824
132
Societal Assets
sum [wants] of people
0
1
11

SLIDER
1050
1143
1196
1176
Needs-Balancing
Needs-Balancing
0
100
1
1
1
NIL
HORIZONTAL

SLIDER
1051
1179
1197
1212
Wants-Balancing
Wants-Balancing
0
5000
100
1
1
NIL
HORIZONTAL

SLIDER
1050
1218
1197
1251
Money-Balancing
Money-Balancing
0
100
1
.1
1
NIL
HORIZONTAL

PLOT
1014
1378
1233
1528
Needs Stock
Time
Reserve
0.0
200.0
0.0
1.0
true
false
"" ""
PENS
"Ave" 1.0 0 -16777216 true "" ""
"Max" 1.0 0 -2674135 true "" ""
"min" 1.0 0 -10899396 true "" ""

BUTTON
850
384
963
417
Manually Industrialise
industrialise
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
1
1064
201
1214
Nurturing Needs
Time
Nurture Needs
0.0
200.0
0.0
1.0
true
false
"" ""
PENS
"Max" 1.0 0 -2674135 true "" ""
"Ave" 1.0 0 -16777216 true "" ""
"Min" 1.0 0 -10899396 true "" ""

PLOT
204
1064
404
1214
Nurturing Tech
Time
Nurturing Tech
0.0
200.0
0.0
1.0
true
false
"" ""
PENS
"Max" 1.0 0 -2674135 true "" ""
"Ave" 1.0 0 -16777216 true "" ""
"Min" 1.0 0 -10899396 true "" ""

PLOT
406
1064
606
1214
Nurturing Money
Time
Nurture Money
0.0
200.0
0.0
1.0
true
false
"" ""
PENS
"Max" 1.0 0 -2674135 true "" ""
"Ave" 1.0 0 -16777216 true "" ""
"Min" 1.0 0 -10899396 true "" ""

PLOT
1
906
201
1056
Mutation
Time
Mutation
0.0
200.0
0.0
0.1
true
false
"" ""
PENS
"Max" 1.0 0 -2674135 true "" ""
"Ave" 1.0 0 -16777216 true "" ""
"Min" 1.0 0 -10899396 true "" ""

PLOT
607
1221
807
1371
Need-Birth-Buffer
Time
Needs
0.0
200.0
0.0
1.0
true
false
"" ""
PENS
"Max" 1.0 0 -2674135 true "" ""
"Ave" 1.0 0 -16777216 true "" ""
"Min" 1.0 0 -10899396 true "" ""

PLOT
51
612
303
762
Economic Cultures
Time
% of Pop
0.0
200.0
0.0
1.0
true
false
"" ""
PENS
"Ind" 1.0 0 -8630108 true "" ""
"HG" 1.0 0 -10899396 true "" ""
"Tr" 1.0 0 -2674135 true "" ""
"In" 1.0 0 -1184463 true "" ""

PLOT
809
1221
1009
1371
Health Choice
Time
% Resources
0.0
200.0
0.0
1.0
true
false
"" ""
PENS
"Max" 1.0 0 -2674135 true "" ""
"Ave" 1.0 0 -16777216 true "" ""
"Min" 1.0 0 -10899396 true "" ""

PLOT
406
907
606
1057
Technological Travel
Time
Amount
0.0
200.0
0.0
1.0
true
false
"" ""
PENS
"Max" 1.0 0 -2674135 true "" ""
"Ave" 1.0 0 -16777216 true "" ""
"Min" 1.0 0 -10899396 true "" ""

PLOT
607
907
807
1057
Vision
Time
Distance
0.0
200.0
0.0
0.01
true
false
"" ""
PENS
"Max" 1.0 0 -2674135 true "" ""
"Ave" 1.0 0 -16777216 true "" ""
"Min" 1.0 0 -10899396 true "" ""
"1" 1.0 0 -955883 true "" ""

PLOT
608
1378
808
1528
Saving Rates
Time
Rates
0.0
200.0
0.0
0.1
true
false
"" ""
PENS
"Needs" 1.0 0 -10899396 true "" ""
"Tech" 1.0 0 -8630108 true "" ""
"Money" 1.0 0 -16777216 true "" ""

SLIDER
1041
1303
1213
1336
Fecundity_Policy
Fecundity_Policy
0
5
0
.1
1
NIL
HORIZONTAL

SLIDER
1041
1266
1213
1299
Child_Limit
Child_Limit
0
5
0
1
1
NIL
HORIZONTAL

SLIDER
1041
1341
1213
1374
Birth_Control
Birth_Control
-5
15
0
1
1
NIL
HORIZONTAL

SLIDER
985
49
1134
82
Stop-simulation
Stop-simulation
0
5000
3500
100
1
NIL
HORIZONTAL

PLOT
408
1378
604
1528
Non-Renewable Reserves
Time
Fixed Resources
0.0
200.0
0.0
10.0
true
false
"" ""
PENS
"Fixed" 1.0 0 -8630108 true "" ""
"Ren" 1.0 0 -10899396 true "" ""

SLIDER
1128
10
1249
43
Eco-Recovery
Eco-Recovery
0
10
0
.1
1
NIL
HORIZONTAL

SLIDER
3
289
142
322
Accidents
Accidents
0
299
0
1
1
NIL
HORIZONTAL

PLOT
811
907
1011
1057
Children by Wealth
Time
Class Fecundity
0.0
200.0
0.0
1.0
true
true
"" ""
PENS
"R" 1.0 0 -14835848 true "" ""
"P" 1.0 0 -2674135 true "" ""

MONITOR
836
137
893
182
Pop Peak
peak-population
0
1
11

BUTTON
1128
86
1222
119
Reset Pop Peak
\nset peak-population 0\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
503
837
674
870
Auto-Naturalisation
Auto-Naturalisation
0
19
0
1
1
NIL
HORIZONTAL

SLIDER
875
421
1073
454
Start-Industrialisation
Start-Industrialisation
0
10000
1700
100
1
NIL
HORIZONTAL

SLIDER
4
323
142
356
Travel-Cost
Travel-Cost
0
.9
0
.01
1
NIL
HORIZONTAL

SLIDER
1020
800
1166
833
Renewable-Economy
Renewable-Economy
0
2
0.5
.1
1
NIL
HORIZONTAL

SLIDER
873
347
1074
380
Start-Renewable-Economy
Start-Renewable-Economy
0
5000
0
10
1
NIL
HORIZONTAL

SLIDER
4
389
142
422
Tech-Medical
Tech-Medical
0
10
0
.1
1
NIL
HORIZONTAL

SLIDER
965
237
1099
270
Initial-Wave1
Initial-Wave1
0
500
390
5
1
NIL
HORIZONTAL

SLIDER
968
384
1103
417
Initial-Wave3
Initial-Wave3
0
400
15
5
1
NIL
HORIZONTAL

BUTTON
849
311
962
344
Manually Innovate
initialise-renewable-economy
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
849
236
961
269
Manually Trade
initialise-trading
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
906
96
977
141
Traders
count people with [industrial-innovate = 1]
0
1
11

MONITOR
907
142
977
187
Innovators
count people with [industrial-innovate = 2]
0
1
11

MONITOR
908
188
978
233
Industrialists
count people with [industrial-innovate = 3]
0
1
11

MONITOR
835
185
894
230
Farmers
count people with [order-of-trade > 5 ] / count people * 100\n                                           
1
1
11

SLIDER
870
801
1009
834
Graphing-Interval
Graphing-Interval
1
100
10
1
1
NIL
HORIZONTAL

MONITOR
581
87
677
132
Fixed Resources
sum [fixed-resources-here] of patches
0
1
11

SLIDER
870
272
1075
305
Start-Trading
Start-Trading
0
2000
700
10
1
NIL
HORIZONTAL

SWITCH
1151
689
1268
722
Colour
Colour
0
1
-1000

SWITCH
1266
492
1383
525
Auto-Advance
Auto-Advance
1
1
-1000

SLIDER
735
10
891
43
Extraordinary-Harshness
Extraordinary-Harshness
0
15
0
.1
1
NIL
HORIZONTAL

SLIDER
734
48
890
81
Ex-Harshness-Amount
Ex-Harshness-Amount
0
200
67
1
1
NIL
HORIZONTAL

SLIDER
1266
530
1384
563
Auto-Shutoff
Auto-Shutoff
0
100
100
1
1
NIL
HORIZONTAL

MONITOR
905
48
977
93
Hunter/Gather
count people with [industrial-innovate = 0]
0
1
11

SLIDER
868
838
1010
871
Start-Graphs
Start-Graphs
0
200
100
1
1
NIL
HORIZONTAL

SLIDER
1140
49
1250
82
Contamination
Contamination
0
4
0
.1
1
NIL
HORIZONTAL

PLOT
832
611
1149
763
Cause of Death
NIL
NIL
0.0
200.0
0.0
0.01
true
true
"" ""
PENS
"Age" 1.0 0 -16777216 true "" ""
"Starve" 1.0 0 -10899396 true "" ""
"Plague" 1.0 0 -8630108 true "" ""
"Disease" 1.0 0 -6459832 true "" ""
"Accident" 1.0 0 -2674135 true "" ""
"Infant" 1.0 0 -2064490 true "" ""

MONITOR
1062
95
1121
140
Population
poptop
0
1
11

MONITOR
1063
141
1121
186
Population
popmid
0
1
11

MONITOR
1063
187
1122
232
Population
poplow
0
1
11

SLIDER
1020
763
1166
796
Industrial-Efficiency
Industrial-Efficiency
.1
10
1
.1
1
NIL
HORIZONTAL

PLOT
1
1221
201
1528
Trading Culture 1
NIL
NIL
0.0
200.0
0.0
1.0
true
true
"" ""
PENS
"1" 1.0 0 -16777216 true "" ""
"2" 1.0 0 -2674135 true "" ""
"3" 1.0 0 -10899396 true "" ""
"4" 1.0 0 -13345367 true "" ""
"5" 1.0 0 -5825686 true "" ""
"6" 1.0 0 -955883 true "" ""

PLOT
204
1221
404
1528
Trading Culture 2
NIL
NIL
0.0
200.0
0.0
1.0
true
true
"" ""
PENS
"1" 1.0 0 -16777216 true "" ""
"2" 1.0 0 -2674135 true "" ""
"3" 1.0 0 -10899396 true "" ""
"4" 1.0 0 -13345367 true "" ""
"5" 1.0 0 -5825686 true "" ""
"6" 1.0 0 -955883 true "" ""

PLOT
406
1221
605
1371
Charity
NIL
NIL
0.0
200.0
0.0
0.6
true
false
"" ""
PENS
"ave" 1.0 0 -16777216 true "" ""
"max" 1.0 0 -2674135 true "" ""
"min" 1.0 0 -10899396 true "" ""

SLIDER
869
764
1009
797
Giving-Threshold
Giving-Threshold
- living-cost
living-cost
0
.1
1
NIL
HORIZONTAL

SLIDER
1265
452
1383
485
Strength
Strength
0
10
5.8
.1
1
NIL
HORIZONTAL

SLIDER
21
764
160
797
Child-Benefit
Child-Benefit
0
2
0
.01
1
NIL
HORIZONTAL

SLIDER
22
801
159
834
Child-Dependency
Child-Dependency
0
16
12
1
1
NIL
HORIZONTAL

SWITCH
897
10
987
43
Pollution
Pollution
1
1
-1000

PLOT
51
459
303
609
Charity Activity
NIL
NIL
0.0
200.0
0.0
0.01
true
true
"" ""
PENS
"Beg" 1.0 0 -6459832 true "" ""
"Give" 1.0 0 -13345367 true "" ""

SLIDER
1271
305
1376
338
Money-supply
Money-supply
0
1000
300
1
1
NIL
HORIZONTAL

PLOT
1020
907
1197
1057
Life Span
NIL
NIL
0.0
200.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

SLIDER
1271
269
1377
302
Fertility-Range
Fertility-Range
0
100
20
1
1
NIL
HORIZONTAL

SLIDER
1265
414
1382
447
Auto-Turnon
Auto-Turnon
0
10000
0
50
1
NIL
HORIZONTAL

SLIDER
1
152
142
185
Old-Age
Old-Age
30
100
75
1
1
NIL
HORIZONTAL

SLIDER
3
424
142
457
Toxicity
Toxicity
0
.9
0
.01
1
NIL
HORIZONTAL

SLIDER
4
356
142
389
Natural-Medical
Natural-Medical
0
5
0
.1
1
NIL
HORIZONTAL

SWITCH
1152
726
1269
759
Wealth-Colour
Wealth-Colour
1
1
-1000

SWITCH
1266
569
1385
602
Pop-Peak-Stop
Pop-Peak-Stop
1
1
-1000

SLIDER
689
764
861
797
Charity-Strength
Charity-Strength
0
10
0
.5
1
NIL
HORIZONTAL

BUTTON
1161
576
1245
609
Reset World
ask patches [ set fixed-resources-here fixed-resources-original\n              set harvest-cost harvest-cost-original\n              set land-usage 0\n              colour-patch ]\nclear-all-plots\n\nask people [die]\nset trading-setting 0\nzero-graph-variables\nset totalpop count people\nreset-ticks\nstop
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1161
614
1247
647
Add Population
setup-people\nask people [ set sell-price-needs 0\n    set sell-price-wants 0\n    set buy-price-needs 0\n    set buy-price-wants 0 ]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
327
842
477
875
Max-Move
Max-Move
0
50
0
1
1
NIL
HORIZONTAL

SLIDER
329
805
477
838
Child-Self-Limit
Child-Self-Limit
0
10
0
.1
1
NIL
HORIZONTAL

SLIDER
326
765
483
798
Max-Market-Vision
Max-Market-Vision
0
30
0
1
1
NIL
HORIZONTAL

SLIDER
164
765
322
798
Need-Birth-Buffer
Need-Birth-Buffer
0
9 * living-cost
9
.1
1
NIL
HORIZONTAL

SWITCH
1284
125
1397
158
Over-Harvest
Over-Harvest
1
1
-1000

SLIDER
1285
199
1397
232
Eco-Decline
Eco-Decline
0
100
18
1
1
NIL
HORIZONTAL

SLIDER
1284
162
1397
195
Eco-Sensitivity
Eco-Sensitivity
0
100
24
1
1
NIL
HORIZONTAL

SLIDER
994
10
1119
43
Impact-Weight
Impact-Weight
-10
10
-2.5
.1
1
NIL
HORIZONTAL

PLOT
317
611
565
761
Gini Coefficient
Time
Gini
0.0
200.0
0.0
1.0
true
false
"" ""
PENS
"gini" 1.0 0 -16777216 true "" ""
"base" 1.0 0 -955883 true "" ""

SLIDER
502
801
674
834
Knowledge-Transfer
Knowledge-Transfer
0
100
0
1
1
NIL
HORIZONTAL

SLIDER
502
765
674
798
Culture-Transfer
Culture-Transfer
0
100
0
1
1
NIL
HORIZONTAL

SLIDER
1286
233
1398
266
Eco-Recovery1
Eco-Recovery1
0
9.9
2.2
.1
1
NIL
HORIZONTAL

SWITCH
178
802
299
835
NBB_Evolve
NBB_Evolve
0
1
-1000

SLIDER
1280
345
1385
378
Starting-Prices
Starting-Prices
0
100
25
1
1
NIL
HORIZONTAL

SLIDER
163
844
322
877
initial-engagement
initial-engagement
0
100
80
1
1
NIL
HORIZONTAL

PLOT
1229
1114
1429
1264
Child Ratio
NIL
NIL
0.0
200.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

SLIDER
1128
251
1257
284
Environment-Seed
Environment-Seed
0
100
3
1
1
NIL
HORIZONTAL

BUTTON
1306
779
1415
812
Manual Seed
random-seed manual-seed
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SWITCH
1129
127
1261
160
Top-Pop-Stop
Top-Pop-Stop
1
1
-1000

SLIDER
1127
168
1254
201
topPop
topPop
0
5000
6000
50
1
NIL
HORIZONTAL

PLOT
1251
1302
1451
1452
class death
death
time
0.0
200.0
0.0
1.0
false
false
"" ""
PENS
"death-child-dep" 1.0 0 -7500403 true "" ""
"rankdeath0" 1.0 0 -2674135 true "" ""
"rankdeath1" 1.0 0 -955883 true "" ""
"rankdeath2" 1.0 0 -6459832 true "" ""

SLIDER
1128
210
1255
243
Agent-Seed
Agent-Seed
0
100
9
1
1
NIL
HORIZONTAL

SLIDER
1111
351
1252
384
manual-seed
manual-seed
0
100
30
1
1
NIL
HORIZONTAL

SWITCH
1111
311
1255
344
Manual-Seed-Switch
Manual-Seed-Switch
0
1
-1000

@#$#@#$#@
## SECTIONS

PROGRAMME OVERVIEW  
BUTTONS, SWTCHES AND SLIDERS  
GRAPHS AND MONITORS  
THE EVOLUTIONARY GRAPHS  
AGENT EVOLUTIONARY VARIABLES  
COPYWRITE NOTICE

Please note: the names of the charts, monitors and the variables in the code were primarily chosen as an aid in remembering what they do. Some of these names do not attempt to reflect neutral scientific concepts. Please do not read too much into how things are named.

## PROGRAMME OVERVIEW

This simulator is designed first and foremost to be an experimental tool. The controls can be extremely sensitive in some setups and then seem barely functional in other setups. It is easy to setup the simulator so that it fails to do anything similar to human society. It is recommended you save the interface [file --> export �> interface] before you make changes so that you can easily find a working setting if new settings become dysfunctional. 

If an interesting run results from your settings, it is advisable to use the 'Reset World' and 'Repopulate' buttons to test the robustness of the trends as the environment will remain unchanged. Using 'Setup' will create a new randomised environment based on your settings. Most rigorously, an experimenter can save the entire world [file --> export --> world] after 'Setup' and before starting a simulation run. This will permit the experiments with the exact same condition. For example, after the initial run, the experimenter could reload the setup from the saved file, cause a single agent to die (type 'ask one-of people [die]' in the command centre), and then do a second run to see what happens.

This simulator is designed so that you can set it up and walk away from it such that it will run for a user set amount of time and then automatically shut off. This way you don't have to sit and watch it. See the 'Pop-Peak-Stop' button and the 'Stop Simulation' slider.

The core of this simulation is designed around three environmental elements and one agent:

'Needs' � a single environmental variable designed to represent renewable resources, such as food, wood (when harvested renewably) and water.

'wants' � a single environmental variable designed to represent the benefits non-renewable resources such as oil or Uranium, medical technology, vehicles, etc.

'Money' � a fixed resource of no intrinsic value but can be traded for either �wants� or �needs�. The money supply is fixed after startup in this version.

'agent' � an evolutionary entity that navigates the simulation environment. It is meant to capture a few key forces generated by human beings in the environment of the world today.

The agents in the simulation can exist in four different states which, in turn, create four different possible agent-generated simulation environments. Somewhat arbitrarily, these four states are called 'Hunter/Gatherer', 'Trading', 'Innovating' and 'Industrial'.

The key characteristics of these four states in their simplest forms are:

'Hunter Gatherer' � (Consisting of Agents and 'Needs')   
Agents look for and harvest food, reproduce (asexually), and die from either lack of food or old age. The environment consists of patches that contain the single renewable food source �needs� and a single non-renewable source called 'wants'. Each has a random amount of resistance covering them that the agent needs to overcome with their 'labour' in order to harvest. �needs� is available in set amounts that is randomly assigned to each patch at the beginning of a simulation run and are renewed once per iteration.
   
Trading � (Consisting of Needs and Money)   
Agents do all of the above and, in addition, they can now buy and sell �needs� using money. 

Innovating � (Consisting of Needs, Wants and Money)  
Agents do all of the above but they now have the choice of converting their �needs� into �wants� simulating the force of turning renewable resources into fixed assets that deteriorate without human intervention. This only occurs in the �innovating� state. 

Industrial � (Consisting of Needs, Wants and Money) 

Agents can now harvest non-renewable �wants� (non-renewable technology) directly from the patches. In this version of the simulation, agents in an 'Industrial' state do not convert 'needs' into 'wants'.

How the agents progress through these stages are controlled by a series of buttons and switches. The user can also introduce a number of complicating elements through the use of the buttons and switches.

## BUTTONS, SWITCHES AND SLIDERS

Accidents � This is a random death that is unmitigated by wealth or medicine. Increasing the number increases the strength. A setting of '0' turns it off.

Auto-Advance � This switch creates a probability of randomly advancing individual agents through the different economic stages by assigning a random agent one level above its current level. Works in conjunction with the 'Strength' slider.

Auto-Naturalisation � This allows the simulation to randomly convert agents to previous levels of economic activity. For example, an 'industrialist' might get converted to a 'trader'. A setting of '0' turns it off. Strength is determined by the position of the slider.

Auto-Shutoff � Once there is a population of 'industrialists' equal to this setting, 'Auto-Advance' is automatically turned off.

Auto-Turnon � This slider automatically switches on 'Auto-Advance' at a given iteration.

Birth-Control � This creates a pressure for the agents to have less children than they naturally would. It differs from 'child-limit' in that 'birth-control' is effective all the time while 'child-limit' becomes progressively more effective as an agent has more children.

Bottom-Wealth-Cutoff-% - See Middle-Wealth-Cutoff-%.

Charity-Strength � Works on setup only. Above '0' this slider causes agents to give 'needs' to agents who are 'begging'. The amount of charity that an agent gives is determined by randomising the number indicated by this slider. See also the 'Giving-Threshold' slider.

Child-Benefit � This simulates taxation and redistribution to children. The higher the slider, the greater the benefit and taxation.

Child-Dependency � This causes new agents to rely on their parents for food. Works in conjunction with 'New-Labour'. If 'Child-Dependency' is set above zero, the effects of the 'infantmort' slider will be constrained to agents within the 'Child-Dependency' range.

Child-Limit � This limits the number of children any agent can have. It simulates the effects of the �Chinese Policy� at a global scale. See also the 'Birth-Control' slider.

Child-Self-Limit � This creates a global force that automatically lowers the fecundity by effecting an agent's probability of having children. It simulates a society-wide wilful decision to have less children.

Colour � This switch colours the agents based on their economic activity. 'Hunter/gatherers' are green, 'traders' are red, 'innovators' are yellow and 'industrialists' are purple. Turning on this switch over-rides the 'Wealth-Colour' switch.

Contamination � This spreads the effects of 'pollution' to neighbouring patches. See 'Pollution'.

Culture-Transfer - This determines the strength of the desire of agents to change their ways to match the richest agent around them. Setting it to '0' turns it off. This is a new slider. The effectiveness of the slider and the effectiveness of using isolated individual characteristics has not yet been thoroughly tested and tuned.

Disease � This simulates individual disease. A setting of 0 turns it off. An agent's resistance to 'disease' can be mitigated by wealth if either of the 'medical' sliders are turned on.

Eco-Recovery � This determines how quickly patches recover from the environmental disruption caused by the harvesting of �wants� (brings down the 'land-usage' variable). Works in conjuction with the 'Pollution' switch and the 'Impact-Weight' slider.

Eco-Sensitivity � This sets up how sensitive a patch can be to over-harvesting of 'needs'. The 'Over-Harvest' switch needs to be turned on for this to work.

Eco-Decline � This determines how quickly patches decline if they are over-harvested. The 'Over-Harvest' switch needs to be turned on for this to work.

Environmental-Degradation �. This slider works with 'Environmental Disruption'. The number set by this slider is the percentage reduction of the maximum 'needs' available. For example, setting the slider to .1 will decrease the maximum possible on a patch by 10% and increase the maximum harshness possible on a patch by 10%. 

Environmental Disruption � This button recalculates the distribution and resistance covering the 'needs' in the patches using the original setup settings. 

Epidemics � This simulates the probability of epidemics. The higher the number, the greater the strength. A setting of 0 turns it off. An agent's resistance to 'epidemics' can be mitigated by wealth if either of the 'medical' sliders are turned on.

Extraordinary-Harshness � This creates patches where it is impossible to harvest 'needs' without a great deal of 'technology.

Ex-Harshness-Amount � This determines how great the 'extraordinary harshness' is. 

Fecundity-Policy �This prevents the global fecundity from increasing beyond a certain level. It is a fantasy population control policy that was included purely for experimentation purposes.

Fertility-Max � This highest possible fertility an agent can have when the simulator is first setup.

Fixed-Harshness � On setup, the programme randomises this number to randomly the resistance covering the fixed �wants� on each patch.

Fixed-Soft-Patch � This is the number of patches that will have its resistance covering �wants� forced to become lower than a single agent�s 'labour'.
   
Giving-Threshold � This determines the level of an agent's 'needs' below which the agent will begin to 'beg'. Works in conjunction with 'charity-strength'. 

Go � Starts and stops the simulation.

Graphing-Interval � This determines how often a plot is made in the graphs. If it is set to '10' the simulation will average the variable for those 10 iterations and graph the result. This was done to make the graphs more readable. Set it to '1' if you wish to see every plot, but the relatively small populations required by personal computers makes the graphical trends much harder to read at this setting.

Impact-Weight - This weights the impact of havesting 'wants' on a patch. Operates during setup only. Works in conjunction with and the 'Pollution' switch and the 'Eco-Recovery' slider.

Industrial-Efficiency � This determines how powerful 'wants' are in the environment.

InfantMort � increases the mortality of agents less than an age of 5 iterations or those considered 'dependent' if the 'Child-Dependency' slider is greater than zero. An agent's resistance to infant mortality can be mitigated by wealth if either of the 'medical' sliders are turned on.

Initial-Wave1 - this determines approximately how many agents will be turned into 'Traders' when either the 'Manually Trade' button is pressed or the simulator iteration reaches the setting of the 'Start-Trading' slider. See also 'Auto-Advance'.

Initial-Wave2 - this determines approximately how many agents will be turned into 'Innovator' when either the 'Manually Innovate' button is pressed or the simulator iteration reaches the setting of the 'Start-Renewable-Economy' slider. See also 'Auto-Advance'.

Initial-Wave3 - this determines approximately how many agents will be turned into 'Industrialists' when either the 'Manually Industrialise' button is pressed or the simulator iteration reaches the setting of the 'Start-Industrialisation' slider. See also 'Auto-Advance'.

Knowledge-Transfer - This determines the strength of the economic transfer to other agents. This will only work if 'Pollution' is turned on in the simulator. Setting it to '0' turns it off. See article for more information. This is a new slider introduced and has yet not been fully tested.

Life-Expectancy-Max � the approximate maximum age an agent can reach.

Living-Cost � how much �needs� is subtracted from the agent each iteration.

Manually Trade - A button that instantly converts agents into 'Traders'. Works in conjunction with the 'Initial-Wave1' slider.

Manually Innovate - A button that instantly converts agents into 'Innovators'. Works in conjunction with the 'Initial-Wave2' slider.

Manually Industrilise - A button that instantly converts agents into 'Industrialists'. Works in conjunction with the 'Initial-Wave3' slider.

Max-Fixed-Resources � On setup, the programme randomises this number to generate the number of �wants� available on each patch. 

Max-Move � This limits the technological boost to movement to the number of patches to which this slider is set. A setting of '0' allows the simulator to choose how far an agent can move. Usually, it chooses a great deal of movement.

Max-Renewable-Resources � On setup, the programme randomises this number to generate the number of �needs� available on each patch. 

Max-Vision-Market � This limits the reach of agents for trading. Set to '0' turns this feature off and when the technology boom begins the richest agents are likely able to trade with any agent in the environment.

Middle-Wealth-Cutoff-% and Bottom-Wealth-Cutoff-% -- These two sliders define the agent�s wealth class used by the graphs. It divides the agents by the percentage of population. For example, if Middle-Wealth-Cutoff-% is set to .90 and Bottom-Wealth-Cutoff-% is set to.40, then the wealthiest will be defined as the wealthiest top 10% of the population, the middle class will be 40% to 90% and the poorest will be defined as the lowest 40%. These sliders influence the graphs only and have no impact on the simulation.

Money-Balancing � see Needs-Balancing 

Money-Supply � This determines the amount of money each agent possesses at start up which then determines the money supply for the duration of the simulation.

Natural-Medical � This uses excess 'needs' to diminish the chance of dying from 'disease�, �InfantMort� and �Epidemics�.

NBB_Evolve - This switch determines whether the amount of 'needs' an agent possesses influences its reproduction rate. See 'Need-Birth-Buffer'.

Needs-Balancing, Wants-Balancing and Money-Balancing � These sliders give weight to each item in regards to what the simulation considers wealth. These sliders influence the graphs only and have no impact on the simulation. Using the internal prices to determine wealth requires larger populations than my computer can sustain to create usable charts.

Need-Birth-Buffer � This slider prevents births unless an agent has a minimum amount of 'needs'. If NBB_Evolve is turned on, on setup the agents randomises the 'Need-Birth-Buffer' setting which then evolves. If it is turned off, all agents accept the 'Need-Birth-Buffer' setting during the simulation. This can be changed during the simulation.

Needs-stock: An evolutionary variable determining how much �needs� an agent requires before seeking to harvest non-renewable �wants�.  
New-Labour � This sets the 'labour' of child dependence to the fraction set by this slider. This is effective when 'Child-Dependency' is set above 0.

num-people � this determines the number of randomly generated agents at the beginning of a simulation run.

Old-Age � The age above which the likelihood of death drastically increases for the agent.

Over-Harvest � This turns on the effect of diminishing harvests if a patch is over harvested. This is used in conjunction with 'Eco-Sensitivity' and 'Eco-Decline'. At the time of writing (20-10-2012) this is a new feature and its effects are yet to be evaluated and calibrated.

Pollution � This turns on the effect of the patch's land-usage variable which increases the resistance to harvesting 'needs'. 

Pop-Peak-Stop � This automatically stops the simulator if the population drops below a certain percentage of the population peak. It is currently set at 15% in the programming. I'm tempted to include a slider to allow the user to alter this at will.

Recycling � This determines how quickly non-renewable resources erode from the system, representing wear and waste. The higher the number, the lower the wear (the more recycling).

Renewable-Economy � This determines how efficient the agents are at converting their renewable resources into technology. This is only relevant to agents working as �Innovators�.

Renewable-Harshness � On setup, the programme randomises this number to generate the resistance covering the �needs� on each patch.

Renewable-Soft-Patch � On setup, this is the number of patches that will have its resistance (harshness) covering �needs� set lower than a single agent�s 'labour'. It allows for a greater range of resistance while maintaining a viable population at the beginning of the simulation.

Re-populate - This generates the number of new agents set by the 'num-people' slider. It is meant to be used in conjuction with the 'Reset World' button. 

Reset Pop Peak � Resets the peak population monitor to the current population. This effects 'Pop-Peak-Stop'.

Reset World - This button clears the graphs and the removes all the agents while resetting the world to an identical state to the last time the 'Setup' button was pressed. If you use this button while the simulation is running you will get an error.

Setup � Sets up the simulation environment and generates the agents.

Start-Graphs � This determines the iteration that the graphs begin to plot. This is included because it takes several iterations for the simulator to settle down and can create extremes that subsequently make the graphs hard to read.

Start-Industrialisation - This slider determines on which interation a number of agents will be converted into 'Traders'. Works in conjunction with the 'Initial-Wave3' slider.

Start-Renewable-Economy - This slider determines on which interation a number of agents will be converted into 'Innovators'. Works in conjunction with the 'Initial-Wave2' slider.

Start-Trading - This slider determines on which interation a number of agents will be converted into 'Traders'. Works in conjunction with the 'Initial-Wave1' slider.

Strength � This determines the strength of 'auto-advance'. The higher the number, the more likely agents will be raised to the next level of economic activity.

Starting-Labour �The number set on Starting-Labour determines the maximum amount an agent can potentially harvest each iteration before �technology� is introduced.

Stop-Simulation � This slider allows the user have the simulation stop at a particular �tick�. It is useful when to comparison runs where the shape of the graphs are important because this will force the graphs to have an identical compression. Also, this allows the user to �set and forget� the simulation and come back later on to see what happened.

Tech-Medical � This uses 'wants' to diminish the chance of dying from 'disease�, �InfantMort� and �Epidemics�.

Toxicity � This increases the effects of disease and epidemics as the patch variable land-usage increases. This simulates a health cost of pollution.

Travel-Cost � This is the cost of that travel in terms of the proportion of �wants� (technology) that was used for that travel.

Wants-Balancing � see Needs-Balancing

Wealth-Colour � This switch colours agents according to their wealth band. Red is poor, yellow is middle income, and purple is rich. The bands are determined by 'Middle-Wealth-Cutoff-%' and 'Bottom-Wealth-Cutoff-%' sliders. The programming is currently set to divide the wealth bands by population (ie. the top 10% of the richest make up the top band) as opposed to using a proportion of total wealth (ie. those people with wealth above certain percentage of wealth are the richest). This switch cannot be turned on if the 'Colour' switch is turned on.

## GRAPHS AND MONITORS

# of Trades / capita � Sums the trades and divides by the population. Purple line is the per capita trading of �wants� and the green line is the per capita trading of �needs�.

Average Age � Ages of the agents has been summed and divided by the population.

Birth and Death � This graphs the total births in that turn divided by the population and the negative of total deaths divided by the population. The middle orange line is 0 and the two red reference lines are currently set at .9 for birth and -.9 for death.

Charity Activity � The brown line charts the percentage of agents who 'begged' and the blue line charts the percentage of agents who 'gave' in a given iteration. See the 'Charity-Strength' and the 'Giving-Threshold' sliders.

Children by Wealth � The turquoise line measures the fecundity of agents in the middle and top wealth bands while the red line measure the fecundity of agents in the bottom wealth band.

Farmers � This monitors the percentage of the population who choose harvesting �needs� over �wants�. As industrialists, these agents will only harvest �wants� if they can�t harvest any �needs� during an iteration. See also the 'Trading Culture 1' and 'Trading Culture 2' graphs and the 'order-of-trade' variable under Evolutionary Variables.

Fecundity � Reports sum of �children� had by the living agents divided by the sum of all agents above the age of 11 (the age they need to be before they can have children).

Fixed-Resources � Sums the patches� �wants�. It is useful to see whether the agents are still harvesting �wants� from the patches when the amounts are too small to register on the graph. See also the 'Non-Renewable Reserves' graph.

Food per Capita - This sums up all the food held by adults in the system and divides it by the population of adults and the 'living-cost'.

Gini Coefficient - This charts the Gini coefficient for this simulated world. The code is borrowed from Uri Wilensky's Sugarscape (see the model library). The user can alter the weight of the three wealth variables (needs, wants, money) by using the 'balancing' sliders. See 'Needs-Balancing' under 'Buttons, Switches and Sliders'.

Hunter/Gatherer � This monitors the population of 'Hunter/Gatherers'.

Industrialists - This monitors the population of 'Industrialists'.

Innovators - This monitors the population of 'Innovators'.

Life Span � This plots the average age of death of the entire population.

Non-Renewable Reserves � Graphs the sum of the patch�s �wants�. See also the 'Fixed-Resources' monitor.

Per Capita Surplus Labour  � This graphs the sum of all the agent�s �needs� divided by the 'living-cost'. If �living-cost� is 3 and there are 10 agents with a total of 24 �needs�, this graph would report back 24 / 10 / 3 = 2.4 / 3 = .8. This means most agents would be living hand to mouth meaning if they didn�t successfully harvest �needs� in the next iteration some would certainly die of starvation. This would mean creating or harvesting non-renewables would be a low priority for most agents. Anything above �1� means the society as a whole has more than 1 turn of excess food.

Population (graph) � Graphs the simulation�s population over time.

Population (monitor) � Reports the number of agents in the simulation at any one time.

Population (monitor beside Wealth Top, Wealth Mid and Wealth Low) - This monitors the population of each wealth band.

Pop Peak � Reports the highest population recorded since the Reset Peak Population button was last pressed. Peak is reset to '0' once the simulator reaches the 'Start-Graphs' iteration.

Prices � Adds up all the prices in that interation and divides them by the number of transactions. The purple line is the price for �wants� and the green line is the price for �needs�. 

Societal Assets � The sum of all non-renewable assets ('wants') held by agents.

Total Wealth per Capita � Sums the agents� �needs� and �wants� and divides by population. As in the per Capita Productivity graph, the �wants� has been suppressed.

Trading Culture 1 - This graphs the six different ways an agent can trade for an agent that is emphasising 'wants' over 'needs' in their harvesting (or work).

Trading Culture 2 - This graphs the six different ways an agent can trade for an agent that is emphasising 'needs' over 'wants' in their harvesting (or work). This group is called 'Farmers' in the simulation.

Traders - This monitors the population of 'Traders'.

Wealth Top, Wealth Mid and Wealth Low � This is the average wealth of the population in each wealth band.

X (Lower Wealth) = Higher Wealth � Using the simulation�s definition of wealth, X is the variable graphed, low wealth is the sum of wealth of the lowest wealth class divided by the population of that class and high wealth is the sum of wealth of the highest wealth class divided by the population of that class.


## THE EVOLUTIONARY GRAPHS

For almost all these graphs, the black line is the system average (the sum of the agent�s variable divided by the agent population) while the red line reports the highest value of this variable held by any agent in the system while the green line reports the lowest value.

Children by Wealth � Reports two variables: the sum of children had by people from the lower class divided by the sum of people in child bearing age in the class and the sum of children had by middle and upper classes divided by the sum of people of child bearing age of these two classes. The red line is the lower class while the turquoise line is the upper and middle classes.

Fertility � Reports the average �fertility� of the lowest class by wealth and the combined average of the middle and upper class by wealth. The turquoise line is the upper and middle classes while the red line is the lower class.

Health-Choice � Reports the variable �propensity-health�

Labour-Choice � Reports the variable �propensity-labour�

Leisure-Choice � Reports the variable �propensity- leisure�

Modern Travel � Reports the variable �migration�. This is how intensively agents use technology to help them move.

Mutation � Reports the variable �mutation�.

Nurturing-Needs � Reports the variable �nurturing-needs�

Nurturing-Tech � Reports the variable �nurturing-wants�

Nurturing-money � Reports the variable �nurturing-money�

Savings Rates � Reports two variables: the sum of savings rates for �needs� divided by the population and the sum of savings rates for �wants� divided by the population. The purple line is �wants� and the green line is �needs�.

Stay at Home � Reports the variable �exploration�. The higher it is, the more likely an agent will be to stay at home.

Vision -- Reports the variable �vision�.

## AGENT EVOLUTIONARY VARIABLES

charity - This determines how much of its excess 'needs' an agent 'gives' when responding to 'begging' agents.

fertile � This determines an agent�s likelihood of having children.

exploration - This determines the likelihood an agent will move away to explore their environment.

industrial-efficiency � Determines how much power each unit of 'wants' has in the environment.

movement � If an agent�s 'needs' income begins to drop, this determines their likelihood of moving off that patch.

movement-wants - If an agent�s 'wants' income begins to drop, this determines their likelihood of moving off that patch.

mutation � This determines the likelihood an agent�s children will mutate on birth. If �mutation� goes to zero, the children will most likely be clones of their parents.

nurture-needs � This determines the percentage of �needs� a parent will give its child on birth.

nurture-wants � This determines the percentage of �wants� a parent will give its child on birth. 

nurture-money � This determines the percentage of �money� a parent will give its child on birth.

price-up � Whenever the agent changes its price up, this is the amount it raises the price.

price-down � Whenever the agent changes its price down, this is the amount it lowers the price.

propensity-health � This determines what percentage of �wants� fights disease.

propensity-labour � This determines what percentage of �wants� is used to increase its labour.

propensity-leisure � This determines what percentage of �wants� does nothing and creates a means for agents to concentrate 'wants' (accumulate capital).

propensity-use-needs � This determines what percentage of excess �needs� an �innovator� will use to convert into �wants�.

savings-rate-needs � This is the amount of �needs� an agent will hoard before selling. All sales occur on amounts surpassing this amount. It is in terms of �living-cost� and so savings will change if the �living-cost� slider is changed.

savings-wants � This is the amount of �wants� and agents keeps for their own use and is not for sale. All sales occur on amounts surpassing this amount. 

vision � This determines the size of the radius in patches that the agent is able to examine before deciding what direction to go. If it goes below 1 (the red line on the graph) the agent is effectively blind to its environment and the direction of its movement will become completely random.

wander � this determines an agent's propensity to jump several patches in order to go exploring.

## CREDITS AND REFERENCES

Copyright 2012 Tim Gooding. All rights reserved.  
Permission to use, modify or redistribute this model is hereby granted, provided that both of the following requirements are followed:   
a) this copyright notice is included.   
b) this model will not be redistributed for profit without permission from Tim Gooding. Contact Tim Gooding for appropriate licenses for redistribution for profit.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.4
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 30 225
Line -7500403 true 150 150 270 225

@#$#@#$#@
0
@#$#@#$#@
